// ignore_for_file: type=lint

import 'package:json_annotation/json_annotation.dart';
import 'package:collection/collection.dart';
import 'dart:convert';

import 'package:chopper/chopper.dart';

import 'client_mapping.dart';
import 'package:chopper/chopper.dart' as chopper;
import 'swagger.enums.swagger.dart' as enums;
export 'swagger.enums.swagger.dart';

part 'swagger.swagger.chopper.dart';
part 'swagger.swagger.g.dart';

// **************************************************************************
// SwaggerChopperGenerator
// **************************************************************************

@ChopperApi()
abstract class Swagger extends ChopperService {
  static Swagger create(
      {ChopperClient? client,
      Authenticator? authenticator,
      String? baseUrl,
      Iterable<dynamic>? interceptors}) {
    if (client != null) {
      return _$Swagger(client);
    }

    final newClient = ChopperClient(
        services: [_$Swagger()],
        converter: $JsonSerializableConverter(),
        interceptors: interceptors ?? [],
        authenticator: authenticator,
        baseUrl: baseUrl ?? 'http://localhost:10014/settings');
    return _$Swagger(newClient);
  }

  ///Gets specified setting value.
  ///@param key Setting key. `*` to get all settings' values.
  Future<chopper.Response<Any>> getSettingKeyGet(
      {required String? key, String? cacheControl}) {
    generatedMapping.putIfAbsent(Any, () => Any.fromJsonFactory);

    return _getSettingKeyGet(key: key, cacheControl: cacheControl);
  }

  ///Gets specified setting value.
  ///@param key Setting key. `*` to get all settings' values.
  @Get(path: '/getSetting/{key}')
  Future<chopper.Response<Any>> _getSettingKeyGet(
      {@Path('key') required String? key,
      @Header('Cache-Control') String? cacheControl});

  ///Gets all settings
  Future<chopper.Response<SettingResponse>> getSettingGet(
      {String? cacheControl}) {
    generatedMapping.putIfAbsent(
        SettingResponse, () => SettingResponse.fromJsonFactory);

    return _getSettingGet(cacheControl: cacheControl);
  }

  ///Gets all settings
  @Get(path: '/getSetting/*')
  Future<chopper.Response<SettingResponse>> _getSettingGet(
      {@Header('Cache-Control') String? cacheControl});

  ///Sets specified setting value.
  ///@param key Setting key.
  ///@param value Setting value.
  Future<chopper.Response> setSettingKeyPut(
      {required String? key, required Any? value, String? cacheControl}) {
    return _setSettingKeyPut(
        key: key, value: value, cacheControl: cacheControl);
  }

  ///Sets specified setting value.
  ///@param key Setting key.
  ///@param value Setting value.
  @Put(path: '/setSetting/{key}')
  Future<chopper.Response> _setSettingKeyPut(
      {@Path('key') required String? key,
      @Body() required Any? value,
      @Header('Cache-Control') String? cacheControl});

  ///Resets specified setting to its default value.
  ///@param key Setting key.
  Future<chopper.Response<Any>> resetSettingKeyPut(
      {required String? key, String? cacheControl}) {
    generatedMapping.putIfAbsent(Any, () => Any.fromJsonFactory);

    return _resetSettingKeyPut(key: key, cacheControl: cacheControl);
  }

  ///Resets specified setting to its default value.
  ///@param key Setting key.
  @Put(path: '/resetSetting/{key}', optionalBody: true)
  Future<chopper.Response<Any>> _resetSettingKeyPut(
      {@Path('key') required String? key,
      @Header('Cache-Control') String? cacheControl});

  ///Gets specified setting value from the remote household device.
  ///@param key Setting key.  Only Personalization Service supported device settings' keys are allowed.
  ///@param cpeId CPE identifier of the remote household device.  Must be different than CPE ID of the local device.
  Future<chopper.Response<Any>> getRemoteSettingKeyGet(
      {required String? key, required String? cpeId, String? cacheControl}) {
    generatedMapping.putIfAbsent(Any, () => Any.fromJsonFactory);

    return _getRemoteSettingKeyGet(
        key: key, cpeId: cpeId, cacheControl: cacheControl);
  }

  ///Gets specified setting value from the remote household device.
  ///@param key Setting key.  Only Personalization Service supported device settings' keys are allowed.
  ///@param cpeId CPE identifier of the remote household device.  Must be different than CPE ID of the local device.
  @Get(path: '/getRemoteSetting/{key}')
  Future<chopper.Response<Any>> _getRemoteSettingKeyGet(
      {@Path('key') required String? key,
      @Query('cpeId') required String? cpeId,
      @Header('Cache-Control') String? cacheControl});

  ///Sets specified setting value of the remote household device.
  ///@param key Setting key.  Only Personalization Service supported device settings' keys are allowed.
  ///@param cpeId CPE identifier of the remote household device.  Must be different than CPE ID of the local device.
  ///@param value Setting value.
  Future<chopper.Response> setRemoteSettingKeyPut(
      {required String? key,
      required String? cpeId,
      required Any? value,
      String? cacheControl}) {
    return _setRemoteSettingKeyPut(
        key: key, cpeId: cpeId, value: value, cacheControl: cacheControl);
  }

  ///Sets specified setting value of the remote household device.
  ///@param key Setting key.  Only Personalization Service supported device settings' keys are allowed.
  ///@param cpeId CPE identifier of the remote household device.  Must be different than CPE ID of the local device.
  ///@param value Setting value.
  @Put(path: '/setRemoteSetting/{key}')
  Future<chopper.Response> _setRemoteSettingKeyPut(
      {@Path('key') required String? key,
      @Query('cpeId') required String? cpeId,
      @Body() required Any? value,
      @Header('Cache-Control') String? cacheControl});

  ///Gets specified settings' values.
  ///@param keys Settings' keys.
  Future<chopper.Response<Any>> getSettingsPut(
      {required List<String>? keys, String? cacheControl}) {
    generatedMapping.putIfAbsent(Any, () => Any.fromJsonFactory);

    return _getSettingsPut(keys: keys, cacheControl: cacheControl);
  }

  ///Gets specified settings' values.
  ///@param keys Settings' keys.
  @Put(path: '/getSettings')
  Future<chopper.Response<Any>> _getSettingsPut(
      {@Body() required List<String>? keys,
      @Header('Cache-Control') String? cacheControl});

  ///Sets specified settings.
  ///@param settings Settings' key-value pairs.
  Future<chopper.Response> setSettingsPut(
      {required Object? settings, String? cacheControl}) {
    return _setSettingsPut(settings: settings, cacheControl: cacheControl);
  }

  ///Sets specified settings.
  ///@param settings Settings' key-value pairs.
  @Put(path: '/setSettings')
  Future<chopper.Response> _setSettingsPut(
      {@Body() required Object? settings,
      @Header('Cache-Control') String? cacheControl});

  ///Settings change event.
  ///@param key Setting key.
  Future<chopper.Response<OnChangeEvent>> settingChangeKeyGet(
      {required String? key, String? cacheControl}) {
    generatedMapping.putIfAbsent(
        OnChangeEvent, () => OnChangeEvent.fromJsonFactory);

    return _settingChangeKeyGet(key: key, cacheControl: cacheControl);
  }

  ///Settings change event.
  ///@param key Setting key.
  @Get(path: '/settingChange/{key}')
  Future<chopper.Response<OnChangeEvent>> _settingChangeKeyGet(
      {@Path('key') required String? key,
      @Header('Cache-Control') String? cacheControl});

  ///Profile switch changes applied event.
  ///
  Future<chopper.Response> profileSwitchChangesAppliedGet(
      {String? cacheControl}) {
    return _profileSwitchChangesAppliedGet(cacheControl: cacheControl);
  }

  ///Profile switch changes applied event.
  ///
  @Get(path: '/profileSwitchChangesApplied')
  Future<chopper.Response> _profileSwitchChangesAppliedGet(
      {@Header('Cache-Control') String? cacheControl});

  ///Service ready for operation event.
  Future<chopper.Response> readyGet({String? cacheControl}) {
    return _readyGet(cacheControl: cacheControl);
  }

  ///Service ready for operation event.
  @Get(path: '/ready')
  Future<chopper.Response> _readyGet(
      {@Header('Cache-Control') String? cacheControl});
}

@JsonSerializable(explicitToJson: true)
class Any {
  Any();

  factory Any.fromJson(Map<String, dynamic> json) => _$AnyFromJson(json);

  static const fromJsonFactory = _$AnyFromJson;
  static const toJsonFactory = _$AnyToJson;
  Map<String, dynamic> toJson() => _$AnyToJson(this);

  @override
  String toString() => jsonEncode(this);

  @override
  int get hashCode => runtimeType.hashCode;
}

@JsonSerializable(explicitToJson: true)
class SettingResponse {
  SettingResponse({
    this.profileOsdLang,
    this.profileAgeLock,
    this.profileAudioLang,
    this.profileAudioDescription,
    this.profileSignLanguage,
    this.profileSubControl,
    this.cpeAudioDolbyDigital,
    this.cpeAudioDolbyDigitalMode,
    this.cpeUseHighContrastUI,
    this.profileSubHardOfHearing,
    this.profileSubLang,
    this.profileSurfFavoriteChannels,
    this.profileOnScreenKeyboardMode,
    this.profileRecentlyUsedSettingsItems,
    this.profileRecentlyUsedAppsItems,
    this.profileTipsAndTricks,
    this.profileRecentlyListenedRadios,
    this.profileAccessibleViews,
    this.profileTextToSpeech,
    this.profileTextToSpeechVoice,
    this.profileTextToSpeechSpeed,
    this.profileTextToSpeechVolume,
    this.cpeRecordPaddingBefore,
    this.cpeRecordPaddingAfter,
    this.customerPersonalSuggestions,
    this.customerAdsOptIn,
    this.customerA2aHgoOptIn,
    this.customerA2aStbOptIn,
    this.cpeFactoryResetState,
    this.cpeIsSilentDowngrade,
    this.cpeHdmiDeviceInfo,
    this.cpeHdmiResolution,
    this.cpePrimaryVideoOutput,
    this.cpeAspectRatio,
    this.cpeHdmiColorOutput,
    this.cpe4by3Handling,
    this.cpe16by9Handling,
    this.cpeAutoTvStartup,
    this.cpeVolume,
    this.cpeWifiClientEnabled,
    this.cpeWifiClientSsid,
    this.cpeWifiClientPass,
    this.cpeAutoStandby,
    this.cpeStandByMode,
    this.cpeShowColdStandByMessage,
    this.cpeShowReplayOptInMessage,
    this.cpeFriendlyName,
    this.cpeQuicksetPairedDevicesInfo,
    this.cpeEnableCEC,
    this.cpeOneTouchViewTurnOffPolicy,
    this.cpeUiTestTools,
    this.cpeSpeedTestResults,
    this.cpeLastUseNetflix,
    this.cpePowerCheck,
    this.cpePowerSource,
    this.cpeDefaultPvrStb,
    this.cpeXaBrokerUrl,
    this.cpeCcsMessages,
    this.cpeDefaultProfileId,
    this.cpeCcAnalogService,
    this.cpeCcDigitalService,
    this.cpeMatchFrameRate,
    this.cpeAskPurchasePin,
    this.cpeAskRecPlayPin,
    this.cpeLockedApps,
    this.customerCustomerId,
    this.customerIsSuspended,
    this.customerIsAdultPinUsed,
    this.customerIsFtiPassed,
    this.customerAppsOptIn,
    this.customerReplayOptIn,
    this.customerReplayOptInTime,
    this.customerDefaultHhStb,
    this.customerCityId,
    this.customerDeleteRecordingReminder,
    this.customerAutoDeleteFunction,
    this.customerRecordingRetentionPeriod,
    this.customerZipCode,
    this.cpeAdsOptInShownForRelease,
    this.cpeDisplayedStandByMessageCount,
    this.cpeSlowStandByCyclesCount,
    this.cpeNetflixRailCache,
    this.cpeNetflixToken,
    this.cpeNetflixVdid,
    this.cpeAudioDelayDD,
    this.cpeAudioDelayPCM,
    this.cpeIsAlexaLinked,
    this.cpeLastUsedBrandedScreenKey,
    this.cpeAppSubscriptions,
  });

  factory SettingResponse.fromJson(Map<String, dynamic> json) =>
      _$SettingResponseFromJson(json);

  @JsonKey(
      name: 'profile.osdLang',
      includeIfNull: false,
      toJson: settingResponseProfileOsdLangToJson,
      fromJson: settingResponseProfileOsdLangProfileOsdLangFromJson)
  final enums.SettingResponseProfileOsdLang? profileOsdLang;

  static enums.SettingResponseProfileOsdLang
      settingResponseProfileOsdLangProfileOsdLangFromJson(Object? value) =>
          settingResponseProfileOsdLangFromJson(
              value, enums.SettingResponseProfileOsdLang.nl);

  @JsonKey(name: 'profile.ageLock', includeIfNull: false)
  final double? profileAgeLock;
  @JsonKey(
      name: 'profile.audioLang',
      includeIfNull: false,
      toJson: settingResponseProfileAudioLangToJson,
      fromJson: settingResponseProfileAudioLangProfileAudioLangFromJson)
  final enums.SettingResponseProfileAudioLang? profileAudioLang;

  static enums.SettingResponseProfileAudioLang
      settingResponseProfileAudioLangProfileAudioLangFromJson(Object? value) =>
          settingResponseProfileAudioLangFromJson(
              value, enums.SettingResponseProfileAudioLang.$null);

  @JsonKey(
      name: 'profile.audioDescription',
      includeIfNull: false,
      defaultValue: false)
  final bool? profileAudioDescription;
  @JsonKey(
      name: 'profile.signLanguage', includeIfNull: false, defaultValue: false)
  final bool? profileSignLanguage;
  @JsonKey(
      name: 'profile.subControl', includeIfNull: false, defaultValue: false)
  final bool? profileSubControl;
  @JsonKey(
      name: 'cpe.audioDolbyDigital', includeIfNull: false, defaultValue: true)
  final bool? cpeAudioDolbyDigital;
  @JsonKey(
      name: 'cpe.audioDolbyDigitalMode',
      includeIfNull: false,
      toJson: settingResponseCpeAudioDolbyDigitalModeToJson,
      fromJson:
          settingResponseCpeAudioDolbyDigitalModeCpeAudioDolbyDigitalModeFromJson)
  final enums.SettingResponseCpeAudioDolbyDigitalMode? cpeAudioDolbyDigitalMode;

  static enums.SettingResponseCpeAudioDolbyDigitalMode
      settingResponseCpeAudioDolbyDigitalModeCpeAudioDolbyDigitalModeFromJson(
              Object? value) =>
          settingResponseCpeAudioDolbyDigitalModeFromJson(
              value, enums.SettingResponseCpeAudioDolbyDigitalMode.$null);

  @JsonKey(
      name: 'cpe.useHighContrastUI', includeIfNull: false, defaultValue: false)
  final bool? cpeUseHighContrastUI;
  @JsonKey(
      name: 'profile.subHardOfHearing',
      includeIfNull: false,
      defaultValue: false)
  final bool? profileSubHardOfHearing;
  @JsonKey(
      name: 'profile.subLang',
      includeIfNull: false,
      toJson: settingResponseProfileSubLangToJson,
      fromJson: settingResponseProfileSubLangProfileSubLangFromJson)
  final enums.SettingResponseProfileSubLang? profileSubLang;

  static enums.SettingResponseProfileSubLang
      settingResponseProfileSubLangProfileSubLangFromJson(Object? value) =>
          settingResponseProfileSubLangFromJson(
              value, enums.SettingResponseProfileSubLang.en);

  @JsonKey(
      name: 'profile.surfFavoriteChannels',
      includeIfNull: false,
      defaultValue: false)
  final bool? profileSurfFavoriteChannels;
  @JsonKey(
      name: 'profile.onScreenKeyboardMode',
      includeIfNull: false,
      toJson: settingResponseProfileOnScreenKeyboardModeToJson,
      fromJson:
          settingResponseProfileOnScreenKeyboardModeProfileOnScreenKeyboardModeFromJson)
  final enums.SettingResponseProfileOnScreenKeyboardMode?
      profileOnScreenKeyboardMode;

  static enums.SettingResponseProfileOnScreenKeyboardMode
      settingResponseProfileOnScreenKeyboardModeProfileOnScreenKeyboardModeFromJson(
              Object? value) =>
          settingResponseProfileOnScreenKeyboardModeFromJson(
              value, enums.SettingResponseProfileOnScreenKeyboardMode.normal);

  @JsonKey(
      name: 'profile.recentlyUsedSettingsItems',
      includeIfNull: false,
      defaultValue: <String>[])
  final List<String>? profileRecentlyUsedSettingsItems;
  @JsonKey(
      name: 'profile.recentlyUsedAppsItems',
      includeIfNull: false,
      defaultValue: <String>[])
  final List<String>? profileRecentlyUsedAppsItems;
  @JsonKey(name: 'profile.tipsAndTricks', includeIfNull: false)
  final SettingResponse$ProfileTipsAndTricks? profileTipsAndTricks;
  @JsonKey(
      name: 'profile.recentlyListenedRadios',
      includeIfNull: false,
      defaultValue: <String>[])
  final List<String>? profileRecentlyListenedRadios;
  @JsonKey(
      name: 'profile.accessibleViews',
      includeIfNull: false,
      defaultValue: <String>[])
  final List<String>? profileAccessibleViews;
  @JsonKey(
      name: 'profile.textToSpeech', includeIfNull: false, defaultValue: false)
  final bool? profileTextToSpeech;
  @JsonKey(name: 'profile.textToSpeechVoice', includeIfNull: false)
  final Map<String, dynamic>? profileTextToSpeechVoice;
  @JsonKey(
      name: 'profile.textToSpeechSpeed',
      includeIfNull: false,
      toJson: settingResponseProfileTextToSpeechSpeedToJson,
      fromJson:
          settingResponseProfileTextToSpeechSpeedProfileTextToSpeechSpeedFromJson)
  final enums.SettingResponseProfileTextToSpeechSpeed? profileTextToSpeechSpeed;

  static enums.SettingResponseProfileTextToSpeechSpeed
      settingResponseProfileTextToSpeechSpeedProfileTextToSpeechSpeedFromJson(
              Object? value) =>
          settingResponseProfileTextToSpeechSpeedFromJson(
              value, enums.SettingResponseProfileTextToSpeechSpeed.average);

  @JsonKey(
      name: 'profile.textToSpeechVolume',
      includeIfNull: false,
      toJson: settingResponseProfileTextToSpeechVolumeToJson,
      fromJson:
          settingResponseProfileTextToSpeechVolumeProfileTextToSpeechVolumeFromJson)
  final enums.SettingResponseProfileTextToSpeechVolume?
      profileTextToSpeechVolume;

  static enums.SettingResponseProfileTextToSpeechVolume
      settingResponseProfileTextToSpeechVolumeProfileTextToSpeechVolumeFromJson(
              Object? value) =>
          settingResponseProfileTextToSpeechVolumeFromJson(
              value, enums.SettingResponseProfileTextToSpeechVolume.value_80);

  @JsonKey(name: 'cpe.recordPaddingBefore', includeIfNull: false)
  final double? cpeRecordPaddingBefore;
  @JsonKey(name: 'cpe.recordPaddingAfter', includeIfNull: false)
  final double? cpeRecordPaddingAfter;
  @JsonKey(name: 'customer.personalSuggestions', includeIfNull: false)
  final bool? customerPersonalSuggestions;
  @JsonKey(name: 'customer.adsOptIn', includeIfNull: false)
  final bool? customerAdsOptIn;
  @JsonKey(name: 'customer.a2aHgoOptIn', includeIfNull: false)
  final bool? customerA2aHgoOptIn;
  @JsonKey(name: 'customer.a2aStbOptIn', includeIfNull: false)
  final bool? customerA2aStbOptIn;
  @JsonKey(
      name: 'cpe.factoryResetState',
      includeIfNull: false,
      toJson: settingResponseCpeFactoryResetStateToJson,
      fromJson: settingResponseCpeFactoryResetStateCpeFactoryResetStateFromJson)
  final enums.SettingResponseCpeFactoryResetState? cpeFactoryResetState;

  static enums.SettingResponseCpeFactoryResetState
      settingResponseCpeFactoryResetStateCpeFactoryResetStateFromJson(
              Object? value) =>
          settingResponseCpeFactoryResetStateFromJson(
              value, enums.SettingResponseCpeFactoryResetState.initial);

  @JsonKey(
      name: 'cpe.isSilentDowngrade', includeIfNull: false, defaultValue: false)
  final bool? cpeIsSilentDowngrade;
  @JsonKey(name: 'cpe.hdmiDeviceInfo', includeIfNull: false)
  final SettingResponse$CpeHdmiDeviceInfo? cpeHdmiDeviceInfo;
  @JsonKey(
      name: 'cpe.hdmiResolution',
      includeIfNull: false,
      toJson: settingResponseCpeHdmiResolutionToJson,
      fromJson: settingResponseCpeHdmiResolutionCpeHdmiResolutionFromJson)
  final enums.SettingResponseCpeHdmiResolution? cpeHdmiResolution;

  static enums.SettingResponseCpeHdmiResolution
      settingResponseCpeHdmiResolutionCpeHdmiResolutionFromJson(
              Object? value) =>
          settingResponseCpeHdmiResolutionFromJson(
              value, enums.SettingResponseCpeHdmiResolution.fromtv);

  @JsonKey(
      name: 'cpe.primaryVideoOutput',
      includeIfNull: false,
      toJson: settingResponseCpePrimaryVideoOutputToJson,
      fromJson:
          settingResponseCpePrimaryVideoOutputCpePrimaryVideoOutputFromJson)
  final enums.SettingResponseCpePrimaryVideoOutput? cpePrimaryVideoOutput;

  static enums.SettingResponseCpePrimaryVideoOutput
      settingResponseCpePrimaryVideoOutputCpePrimaryVideoOutputFromJson(
              Object? value) =>
          settingResponseCpePrimaryVideoOutputFromJson(
              value, enums.SettingResponseCpePrimaryVideoOutput.hdmi);

  @JsonKey(
      name: 'cpe.aspectRatio',
      includeIfNull: false,
      toJson: settingResponseCpeAspectRatioToJson,
      fromJson: settingResponseCpeAspectRatioCpeAspectRatioFromJson)
  final enums.SettingResponseCpeAspectRatio? cpeAspectRatio;

  static enums.SettingResponseCpeAspectRatio
      settingResponseCpeAspectRatioCpeAspectRatioFromJson(Object? value) =>
          settingResponseCpeAspectRatioFromJson(
              value, enums.SettingResponseCpeAspectRatio.value_169);

  @JsonKey(
      name: 'cpe.hdmiColorOutput',
      includeIfNull: false,
      toJson: settingResponseCpeHdmiColorOutputToJson,
      fromJson: settingResponseCpeHdmiColorOutputCpeHdmiColorOutputFromJson)
  final enums.SettingResponseCpeHdmiColorOutput? cpeHdmiColorOutput;

  static enums.SettingResponseCpeHdmiColorOutput
      settingResponseCpeHdmiColorOutputCpeHdmiColorOutputFromJson(
              Object? value) =>
          settingResponseCpeHdmiColorOutputFromJson(
              value, enums.SettingResponseCpeHdmiColorOutput.auto);

  @JsonKey(
      name: 'cpe.4by3Handling',
      includeIfNull: false,
      toJson: settingResponseCpe4by3HandlingToJson,
      fromJson: settingResponseCpe4by3HandlingCpe4by3HandlingFromJson)
  final enums.SettingResponseCpe4by3Handling? cpe4by3Handling;

  static enums.SettingResponseCpe4by3Handling
      settingResponseCpe4by3HandlingCpe4by3HandlingFromJson(Object? value) =>
          settingResponseCpe4by3HandlingFromJson(
              value, enums.SettingResponseCpe4by3Handling.fullmode);

  @JsonKey(
      name: 'cpe.16by9Handling',
      includeIfNull: false,
      toJson: settingResponseCpe16by9HandlingToJson,
      fromJson: settingResponseCpe16by9HandlingCpe16by9HandlingFromJson)
  final enums.SettingResponseCpe16by9Handling? cpe16by9Handling;

  static enums.SettingResponseCpe16by9Handling
      settingResponseCpe16by9HandlingCpe16by9HandlingFromJson(Object? value) =>
          settingResponseCpe16by9HandlingFromJson(
              value, enums.SettingResponseCpe16by9Handling.fullscreen);

  @JsonKey(name: 'cpe.autoTvStartup', includeIfNull: false, defaultValue: true)
  final bool? cpeAutoTvStartup;
  @JsonKey(name: 'cpe.volume', includeIfNull: false)
  final double? cpeVolume;
  @JsonKey(
      name: 'cpe.wifiClientEnabled', includeIfNull: false, defaultValue: false)
  final bool? cpeWifiClientEnabled;
  @JsonKey(name: 'cpe.wifiClientSsid', includeIfNull: false, defaultValue: '')
  final String? cpeWifiClientSsid;
  @JsonKey(name: 'cpe.wifiClientPass', includeIfNull: false, defaultValue: '')
  final String? cpeWifiClientPass;
  @JsonKey(name: 'cpe.autoStandby', includeIfNull: false)
  final double? cpeAutoStandby;
  @JsonKey(
      name: 'cpe.standByMode',
      includeIfNull: false,
      toJson: settingResponseCpeStandByModeToJson,
      fromJson: settingResponseCpeStandByModeCpeStandByModeFromJson)
  final enums.SettingResponseCpeStandByMode? cpeStandByMode;

  static enums.SettingResponseCpeStandByMode
      settingResponseCpeStandByModeCpeStandByModeFromJson(Object? value) =>
          settingResponseCpeStandByModeFromJson(
              value, enums.SettingResponseCpeStandByMode.coldstandby);

  @JsonKey(
      name: 'cpe.showColdStandByMessage',
      includeIfNull: false,
      defaultValue: true)
  final bool? cpeShowColdStandByMessage;
  @JsonKey(
      name: 'cpe.showReplayOptInMessage',
      includeIfNull: false,
      defaultValue: true)
  final bool? cpeShowReplayOptInMessage;
  @JsonKey(name: 'cpe.friendlyName', includeIfNull: false, defaultValue: '')
  final String? cpeFriendlyName;
  @JsonKey(name: 'cpe.quicksetPairedDevicesInfo', includeIfNull: false)
  final SettingResponse$CpeQuicksetPairedDevicesInfo?
      cpeQuicksetPairedDevicesInfo;
  @JsonKey(name: 'cpe.enableCEC', includeIfNull: false, defaultValue: true)
  final bool? cpeEnableCEC;
  @JsonKey(
      name: 'cpe.oneTouchViewTurnOffPolicy',
      includeIfNull: false,
      defaultValue: true)
  final bool? cpeOneTouchViewTurnOffPolicy;
  @JsonKey(name: 'cpe.uiTestTools', includeIfNull: false, defaultValue: false)
  final bool? cpeUiTestTools;
  @JsonKey(
      name: 'cpe.speedTestResults',
      includeIfNull: false,
      defaultValue: <SettingResponse$CpeSpeedTestResults>[])
  final List<SettingResponse$CpeSpeedTestResults>? cpeSpeedTestResults;
  @JsonKey(name: 'cpe.lastUseNetflix', includeIfNull: false)
  final double? cpeLastUseNetflix;
  @JsonKey(
      name: 'cpe.powerCheck',
      includeIfNull: false,
      toJson: settingResponseCpePowerCheckToJson,
      fromJson: settingResponseCpePowerCheckCpePowerCheckFromJson)
  final enums.SettingResponseCpePowerCheck? cpePowerCheck;

  static enums.SettingResponseCpePowerCheck
      settingResponseCpePowerCheckCpePowerCheckFromJson(Object? value) =>
          settingResponseCpePowerCheckFromJson(
              value, enums.SettingResponseCpePowerCheck.$null);

  @JsonKey(
      name: 'cpe.powerSource',
      includeIfNull: false,
      toJson: settingResponseCpePowerSourceToJson,
      fromJson: settingResponseCpePowerSourceCpePowerSourceFromJson)
  final enums.SettingResponseCpePowerSource? cpePowerSource;

  static enums.SettingResponseCpePowerSource
      settingResponseCpePowerSourceCpePowerSourceFromJson(Object? value) =>
          settingResponseCpePowerSourceFromJson(
              value, enums.SettingResponseCpePowerSource.$null);

  @JsonKey(name: 'cpe.defaultPvrStb', includeIfNull: false, defaultValue: '')
  final String? cpeDefaultPvrStb;
  @JsonKey(name: 'cpe.xaBrokerUrl', includeIfNull: false, defaultValue: '')
  final String? cpeXaBrokerUrl;
  @JsonKey(
      name: 'cpe.ccsMessages', includeIfNull: false, defaultValue: <String>[])
  final List<String>? cpeCcsMessages;
  @JsonKey(name: 'cpe.defaultProfileId', includeIfNull: false, defaultValue: '')
  final String? cpeDefaultProfileId;
  @JsonKey(
      name: 'cpe.ccAnalogService',
      includeIfNull: false,
      toJson: settingResponseCpeCcAnalogServiceToJson,
      fromJson: settingResponseCpeCcAnalogServiceCpeCcAnalogServiceFromJson)
  final enums.SettingResponseCpeCcAnalogService? cpeCcAnalogService;

  static enums.SettingResponseCpeCcAnalogService
      settingResponseCpeCcAnalogServiceCpeCcAnalogServiceFromJson(
              Object? value) =>
          settingResponseCpeCcAnalogServiceFromJson(
              value, enums.SettingResponseCpeCcAnalogService.cc1);

  @JsonKey(
      name: 'cpe.ccDigitalService',
      includeIfNull: false,
      toJson: settingResponseCpeCcDigitalServiceToJson,
      fromJson: settingResponseCpeCcDigitalServiceCpeCcDigitalServiceFromJson)
  final enums.SettingResponseCpeCcDigitalService? cpeCcDigitalService;

  static enums.SettingResponseCpeCcDigitalService
      settingResponseCpeCcDigitalServiceCpeCcDigitalServiceFromJson(
              Object? value) =>
          settingResponseCpeCcDigitalServiceFromJson(
              value, enums.SettingResponseCpeCcDigitalService.primary);

  @JsonKey(
      name: 'cpe.matchFrameRate', includeIfNull: false, defaultValue: false)
  final bool? cpeMatchFrameRate;
  @JsonKey(name: 'cpe.askPurchasePin', includeIfNull: false, defaultValue: true)
  final bool? cpeAskPurchasePin;
  @JsonKey(name: 'cpe.askRecPlayPin', includeIfNull: false, defaultValue: true)
  final bool? cpeAskRecPlayPin;
  @JsonKey(
      name: 'cpe.lockedApps', includeIfNull: false, defaultValue: <String>[])
  final List<String>? cpeLockedApps;
  @JsonKey(name: 'customer.customerId', includeIfNull: false, defaultValue: '')
  final String? customerCustomerId;
  @JsonKey(
      name: 'customer.isSuspended', includeIfNull: false, defaultValue: false)
  final bool? customerIsSuspended;
  @JsonKey(
      name: 'customer.isAdultPinUsed',
      includeIfNull: false,
      defaultValue: false)
  final bool? customerIsAdultPinUsed;
  @JsonKey(
      name: 'customer.isFtiPassed', includeIfNull: false, defaultValue: false)
  final bool? customerIsFtiPassed;
  @JsonKey(
      name: 'customer.appsOptIn', includeIfNull: false, defaultValue: false)
  final bool? customerAppsOptIn;
  @JsonKey(name: 'customer.replayOptIn', includeIfNull: false)
  final bool? customerReplayOptIn;
  @JsonKey(name: 'customer.replayOptInTime', includeIfNull: false)
  final double? customerReplayOptInTime;
  @JsonKey(
      name: 'customer.defaultHhStb', includeIfNull: false, defaultValue: '')
  final String? customerDefaultHhStb;
  @JsonKey(name: 'customer.cityId', includeIfNull: false, defaultValue: '')
  final String? customerCityId;
  @JsonKey(
      name: 'customer.deleteRecordingReminder',
      includeIfNull: false,
      defaultValue: false)
  final bool? customerDeleteRecordingReminder;
  @JsonKey(
      name: 'customer.autoDeleteFunction',
      includeIfNull: false,
      defaultValue: false)
  final bool? customerAutoDeleteFunction;
  @JsonKey(name: 'customer.recordingRetentionPeriod', includeIfNull: false)
  final double? customerRecordingRetentionPeriod;
  @JsonKey(name: 'customer.zipCode', includeIfNull: false, defaultValue: '')
  final String? customerZipCode;
  @JsonKey(
      name: 'cpe.adsOptInShownForRelease',
      includeIfNull: false,
      defaultValue: '')
  final String? cpeAdsOptInShownForRelease;
  @JsonKey(name: 'cpe.displayedStandByMessageCount', includeIfNull: false)
  final int? cpeDisplayedStandByMessageCount;
  @JsonKey(name: 'cpe.slowStandByCyclesCount', includeIfNull: false)
  final int? cpeSlowStandByCyclesCount;
  @JsonKey(name: 'cpe.netflixRailCache', includeIfNull: false, defaultValue: '')
  final String? cpeNetflixRailCache;
  @JsonKey(name: 'cpe.netflixToken', includeIfNull: false, defaultValue: '')
  final String? cpeNetflixToken;
  @JsonKey(name: 'cpe.netflixVdid', includeIfNull: false, defaultValue: '')
  final String? cpeNetflixVdid;
  @JsonKey(name: 'cpe.audioDelayDD', includeIfNull: false)
  final int? cpeAudioDelayDD;
  @JsonKey(name: 'cpe.audioDelayPCM', includeIfNull: false)
  final int? cpeAudioDelayPCM;
  @JsonKey(name: 'cpe.isAlexaLinked', includeIfNull: false, defaultValue: false)
  final bool? cpeIsAlexaLinked;
  @JsonKey(
      name: 'cpe.lastUsedBrandedScreenKey',
      includeIfNull: false,
      defaultValue: '')
  final String? cpeLastUsedBrandedScreenKey;
  @JsonKey(name: 'cpe.appSubscriptions', includeIfNull: false)
  final Map<String, dynamic>? cpeAppSubscriptions;
  static const fromJsonFactory = _$SettingResponseFromJson;
  static const toJsonFactory = _$SettingResponseToJson;
  Map<String, dynamic> toJson() => _$SettingResponseToJson(this);

  @override
  String toString() => jsonEncode(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is SettingResponse &&
            (identical(other.profileOsdLang, profileOsdLang) ||
                const DeepCollectionEquality()
                    .equals(other.profileOsdLang, profileOsdLang)) &&
            (identical(other.profileAgeLock, profileAgeLock) ||
                const DeepCollectionEquality()
                    .equals(other.profileAgeLock, profileAgeLock)) &&
            (identical(other.profileAudioLang, profileAudioLang) ||
                const DeepCollectionEquality()
                    .equals(other.profileAudioLang, profileAudioLang)) &&
            (identical(other.profileAudioDescription, profileAudioDescription) ||
                const DeepCollectionEquality().equals(
                    other.profileAudioDescription, profileAudioDescription)) &&
            (identical(other.profileSignLanguage, profileSignLanguage) ||
                const DeepCollectionEquality()
                    .equals(other.profileSignLanguage, profileSignLanguage)) &&
            (identical(other.profileSubControl, profileSubControl) ||
                const DeepCollectionEquality()
                    .equals(other.profileSubControl, profileSubControl)) &&
            (identical(other.cpeAudioDolbyDigital, cpeAudioDolbyDigital) ||
                const DeepCollectionEquality().equals(
                    other.cpeAudioDolbyDigital, cpeAudioDolbyDigital)) &&
            (identical(other.cpeAudioDolbyDigitalMode, cpeAudioDolbyDigitalMode) ||
                const DeepCollectionEquality().equals(
                    other.cpeAudioDolbyDigitalMode,
                    cpeAudioDolbyDigitalMode)) &&
            (identical(other.cpeUseHighContrastUI, cpeUseHighContrastUI) ||
                const DeepCollectionEquality().equals(
                    other.cpeUseHighContrastUI, cpeUseHighContrastUI)) &&
            (identical(other.profileSubHardOfHearing, profileSubHardOfHearing) ||
                const DeepCollectionEquality().equals(
                    other.profileSubHardOfHearing, profileSubHardOfHearing)) &&
            (identical(other.profileSubLang, profileSubLang) ||
                const DeepCollectionEquality()
                    .equals(other.profileSubLang, profileSubLang)) &&
            (identical(other.profileSurfFavoriteChannels, profileSurfFavoriteChannels) ||
                const DeepCollectionEquality().equals(
                    other.profileSurfFavoriteChannels,
                    profileSurfFavoriteChannels)) &&
            (identical(other.profileOnScreenKeyboardMode, profileOnScreenKeyboardMode) ||
                const DeepCollectionEquality().equals(
                    other.profileOnScreenKeyboardMode, profileOnScreenKeyboardMode)) &&
            (identical(other.profileRecentlyUsedSettingsItems, profileRecentlyUsedSettingsItems) || const DeepCollectionEquality().equals(other.profileRecentlyUsedSettingsItems, profileRecentlyUsedSettingsItems)) &&
            (identical(other.profileRecentlyUsedAppsItems, profileRecentlyUsedAppsItems) || const DeepCollectionEquality().equals(other.profileRecentlyUsedAppsItems, profileRecentlyUsedAppsItems)) &&
            (identical(other.profileTipsAndTricks, profileTipsAndTricks) || const DeepCollectionEquality().equals(other.profileTipsAndTricks, profileTipsAndTricks)) &&
            (identical(other.profileRecentlyListenedRadios, profileRecentlyListenedRadios) || const DeepCollectionEquality().equals(other.profileRecentlyListenedRadios, profileRecentlyListenedRadios)) &&
            (identical(other.profileAccessibleViews, profileAccessibleViews) || const DeepCollectionEquality().equals(other.profileAccessibleViews, profileAccessibleViews)) &&
            (identical(other.profileTextToSpeech, profileTextToSpeech) || const DeepCollectionEquality().equals(other.profileTextToSpeech, profileTextToSpeech)) &&
            (identical(other.profileTextToSpeechVoice, profileTextToSpeechVoice) || const DeepCollectionEquality().equals(other.profileTextToSpeechVoice, profileTextToSpeechVoice)) &&
            (identical(other.profileTextToSpeechSpeed, profileTextToSpeechSpeed) || const DeepCollectionEquality().equals(other.profileTextToSpeechSpeed, profileTextToSpeechSpeed)) &&
            (identical(other.profileTextToSpeechVolume, profileTextToSpeechVolume) || const DeepCollectionEquality().equals(other.profileTextToSpeechVolume, profileTextToSpeechVolume)) &&
            (identical(other.cpeRecordPaddingBefore, cpeRecordPaddingBefore) || const DeepCollectionEquality().equals(other.cpeRecordPaddingBefore, cpeRecordPaddingBefore)) &&
            (identical(other.cpeRecordPaddingAfter, cpeRecordPaddingAfter) || const DeepCollectionEquality().equals(other.cpeRecordPaddingAfter, cpeRecordPaddingAfter)) &&
            (identical(other.customerPersonalSuggestions, customerPersonalSuggestions) || const DeepCollectionEquality().equals(other.customerPersonalSuggestions, customerPersonalSuggestions)) &&
            (identical(other.customerAdsOptIn, customerAdsOptIn) || const DeepCollectionEquality().equals(other.customerAdsOptIn, customerAdsOptIn)) &&
            (identical(other.customerA2aHgoOptIn, customerA2aHgoOptIn) || const DeepCollectionEquality().equals(other.customerA2aHgoOptIn, customerA2aHgoOptIn)) &&
            (identical(other.customerA2aStbOptIn, customerA2aStbOptIn) || const DeepCollectionEquality().equals(other.customerA2aStbOptIn, customerA2aStbOptIn)) &&
            (identical(other.cpeFactoryResetState, cpeFactoryResetState) || const DeepCollectionEquality().equals(other.cpeFactoryResetState, cpeFactoryResetState)) &&
            (identical(other.cpeIsSilentDowngrade, cpeIsSilentDowngrade) || const DeepCollectionEquality().equals(other.cpeIsSilentDowngrade, cpeIsSilentDowngrade)) &&
            (identical(other.cpeHdmiDeviceInfo, cpeHdmiDeviceInfo) || const DeepCollectionEquality().equals(other.cpeHdmiDeviceInfo, cpeHdmiDeviceInfo)) &&
            (identical(other.cpeHdmiResolution, cpeHdmiResolution) || const DeepCollectionEquality().equals(other.cpeHdmiResolution, cpeHdmiResolution)) &&
            (identical(other.cpePrimaryVideoOutput, cpePrimaryVideoOutput) || const DeepCollectionEquality().equals(other.cpePrimaryVideoOutput, cpePrimaryVideoOutput)) &&
            (identical(other.cpeAspectRatio, cpeAspectRatio) || const DeepCollectionEquality().equals(other.cpeAspectRatio, cpeAspectRatio)) &&
            (identical(other.cpeHdmiColorOutput, cpeHdmiColorOutput) || const DeepCollectionEquality().equals(other.cpeHdmiColorOutput, cpeHdmiColorOutput)) &&
            (identical(other.cpe4by3Handling, cpe4by3Handling) || const DeepCollectionEquality().equals(other.cpe4by3Handling, cpe4by3Handling)) &&
            (identical(other.cpe16by9Handling, cpe16by9Handling) || const DeepCollectionEquality().equals(other.cpe16by9Handling, cpe16by9Handling)) &&
            (identical(other.cpeAutoTvStartup, cpeAutoTvStartup) || const DeepCollectionEquality().equals(other.cpeAutoTvStartup, cpeAutoTvStartup)) &&
            (identical(other.cpeVolume, cpeVolume) || const DeepCollectionEquality().equals(other.cpeVolume, cpeVolume)) &&
            (identical(other.cpeWifiClientEnabled, cpeWifiClientEnabled) || const DeepCollectionEquality().equals(other.cpeWifiClientEnabled, cpeWifiClientEnabled)) &&
            (identical(other.cpeWifiClientSsid, cpeWifiClientSsid) || const DeepCollectionEquality().equals(other.cpeWifiClientSsid, cpeWifiClientSsid)) &&
            (identical(other.cpeWifiClientPass, cpeWifiClientPass) || const DeepCollectionEquality().equals(other.cpeWifiClientPass, cpeWifiClientPass)) &&
            (identical(other.cpeAutoStandby, cpeAutoStandby) || const DeepCollectionEquality().equals(other.cpeAutoStandby, cpeAutoStandby)) &&
            (identical(other.cpeStandByMode, cpeStandByMode) || const DeepCollectionEquality().equals(other.cpeStandByMode, cpeStandByMode)) &&
            (identical(other.cpeShowColdStandByMessage, cpeShowColdStandByMessage) || const DeepCollectionEquality().equals(other.cpeShowColdStandByMessage, cpeShowColdStandByMessage)) &&
            (identical(other.cpeShowReplayOptInMessage, cpeShowReplayOptInMessage) || const DeepCollectionEquality().equals(other.cpeShowReplayOptInMessage, cpeShowReplayOptInMessage)) &&
            (identical(other.cpeFriendlyName, cpeFriendlyName) || const DeepCollectionEquality().equals(other.cpeFriendlyName, cpeFriendlyName)) &&
            (identical(other.cpeQuicksetPairedDevicesInfo, cpeQuicksetPairedDevicesInfo) || const DeepCollectionEquality().equals(other.cpeQuicksetPairedDevicesInfo, cpeQuicksetPairedDevicesInfo)) &&
            (identical(other.cpeEnableCEC, cpeEnableCEC) || const DeepCollectionEquality().equals(other.cpeEnableCEC, cpeEnableCEC)) &&
            (identical(other.cpeOneTouchViewTurnOffPolicy, cpeOneTouchViewTurnOffPolicy) || const DeepCollectionEquality().equals(other.cpeOneTouchViewTurnOffPolicy, cpeOneTouchViewTurnOffPolicy)) &&
            (identical(other.cpeUiTestTools, cpeUiTestTools) || const DeepCollectionEquality().equals(other.cpeUiTestTools, cpeUiTestTools)) &&
            (identical(other.cpeSpeedTestResults, cpeSpeedTestResults) || const DeepCollectionEquality().equals(other.cpeSpeedTestResults, cpeSpeedTestResults)) &&
            (identical(other.cpeLastUseNetflix, cpeLastUseNetflix) || const DeepCollectionEquality().equals(other.cpeLastUseNetflix, cpeLastUseNetflix)) &&
            (identical(other.cpePowerCheck, cpePowerCheck) || const DeepCollectionEquality().equals(other.cpePowerCheck, cpePowerCheck)) &&
            (identical(other.cpePowerSource, cpePowerSource) || const DeepCollectionEquality().equals(other.cpePowerSource, cpePowerSource)) &&
            (identical(other.cpeDefaultPvrStb, cpeDefaultPvrStb) || const DeepCollectionEquality().equals(other.cpeDefaultPvrStb, cpeDefaultPvrStb)) &&
            (identical(other.cpeXaBrokerUrl, cpeXaBrokerUrl) || const DeepCollectionEquality().equals(other.cpeXaBrokerUrl, cpeXaBrokerUrl)) &&
            (identical(other.cpeCcsMessages, cpeCcsMessages) || const DeepCollectionEquality().equals(other.cpeCcsMessages, cpeCcsMessages)) &&
            (identical(other.cpeDefaultProfileId, cpeDefaultProfileId) || const DeepCollectionEquality().equals(other.cpeDefaultProfileId, cpeDefaultProfileId)) &&
            (identical(other.cpeCcAnalogService, cpeCcAnalogService) || const DeepCollectionEquality().equals(other.cpeCcAnalogService, cpeCcAnalogService)) &&
            (identical(other.cpeCcDigitalService, cpeCcDigitalService) || const DeepCollectionEquality().equals(other.cpeCcDigitalService, cpeCcDigitalService)) &&
            (identical(other.cpeMatchFrameRate, cpeMatchFrameRate) || const DeepCollectionEquality().equals(other.cpeMatchFrameRate, cpeMatchFrameRate)) &&
            (identical(other.cpeAskPurchasePin, cpeAskPurchasePin) || const DeepCollectionEquality().equals(other.cpeAskPurchasePin, cpeAskPurchasePin)) &&
            (identical(other.cpeAskRecPlayPin, cpeAskRecPlayPin) || const DeepCollectionEquality().equals(other.cpeAskRecPlayPin, cpeAskRecPlayPin)) &&
            (identical(other.cpeLockedApps, cpeLockedApps) || const DeepCollectionEquality().equals(other.cpeLockedApps, cpeLockedApps)) &&
            (identical(other.customerCustomerId, customerCustomerId) || const DeepCollectionEquality().equals(other.customerCustomerId, customerCustomerId)) &&
            (identical(other.customerIsSuspended, customerIsSuspended) || const DeepCollectionEquality().equals(other.customerIsSuspended, customerIsSuspended)) &&
            (identical(other.customerIsAdultPinUsed, customerIsAdultPinUsed) || const DeepCollectionEquality().equals(other.customerIsAdultPinUsed, customerIsAdultPinUsed)) &&
            (identical(other.customerIsFtiPassed, customerIsFtiPassed) || const DeepCollectionEquality().equals(other.customerIsFtiPassed, customerIsFtiPassed)) &&
            (identical(other.customerAppsOptIn, customerAppsOptIn) || const DeepCollectionEquality().equals(other.customerAppsOptIn, customerAppsOptIn)) &&
            (identical(other.customerReplayOptIn, customerReplayOptIn) || const DeepCollectionEquality().equals(other.customerReplayOptIn, customerReplayOptIn)) &&
            (identical(other.customerReplayOptInTime, customerReplayOptInTime) || const DeepCollectionEquality().equals(other.customerReplayOptInTime, customerReplayOptInTime)) &&
            (identical(other.customerDefaultHhStb, customerDefaultHhStb) || const DeepCollectionEquality().equals(other.customerDefaultHhStb, customerDefaultHhStb)) &&
            (identical(other.customerCityId, customerCityId) || const DeepCollectionEquality().equals(other.customerCityId, customerCityId)) &&
            (identical(other.customerDeleteRecordingReminder, customerDeleteRecordingReminder) || const DeepCollectionEquality().equals(other.customerDeleteRecordingReminder, customerDeleteRecordingReminder)) &&
            (identical(other.customerAutoDeleteFunction, customerAutoDeleteFunction) || const DeepCollectionEquality().equals(other.customerAutoDeleteFunction, customerAutoDeleteFunction)) &&
            (identical(other.customerRecordingRetentionPeriod, customerRecordingRetentionPeriod) || const DeepCollectionEquality().equals(other.customerRecordingRetentionPeriod, customerRecordingRetentionPeriod)) &&
            (identical(other.customerZipCode, customerZipCode) || const DeepCollectionEquality().equals(other.customerZipCode, customerZipCode)) &&
            (identical(other.cpeAdsOptInShownForRelease, cpeAdsOptInShownForRelease) || const DeepCollectionEquality().equals(other.cpeAdsOptInShownForRelease, cpeAdsOptInShownForRelease)) &&
            (identical(other.cpeDisplayedStandByMessageCount, cpeDisplayedStandByMessageCount) || const DeepCollectionEquality().equals(other.cpeDisplayedStandByMessageCount, cpeDisplayedStandByMessageCount)) &&
            (identical(other.cpeSlowStandByCyclesCount, cpeSlowStandByCyclesCount) || const DeepCollectionEquality().equals(other.cpeSlowStandByCyclesCount, cpeSlowStandByCyclesCount)) &&
            (identical(other.cpeNetflixRailCache, cpeNetflixRailCache) || const DeepCollectionEquality().equals(other.cpeNetflixRailCache, cpeNetflixRailCache)) &&
            (identical(other.cpeNetflixToken, cpeNetflixToken) || const DeepCollectionEquality().equals(other.cpeNetflixToken, cpeNetflixToken)) &&
            (identical(other.cpeNetflixVdid, cpeNetflixVdid) || const DeepCollectionEquality().equals(other.cpeNetflixVdid, cpeNetflixVdid)) &&
            (identical(other.cpeAudioDelayDD, cpeAudioDelayDD) || const DeepCollectionEquality().equals(other.cpeAudioDelayDD, cpeAudioDelayDD)) &&
            (identical(other.cpeAudioDelayPCM, cpeAudioDelayPCM) || const DeepCollectionEquality().equals(other.cpeAudioDelayPCM, cpeAudioDelayPCM)) &&
            (identical(other.cpeIsAlexaLinked, cpeIsAlexaLinked) || const DeepCollectionEquality().equals(other.cpeIsAlexaLinked, cpeIsAlexaLinked)) &&
            (identical(other.cpeLastUsedBrandedScreenKey, cpeLastUsedBrandedScreenKey) || const DeepCollectionEquality().equals(other.cpeLastUsedBrandedScreenKey, cpeLastUsedBrandedScreenKey)) &&
            (identical(other.cpeAppSubscriptions, cpeAppSubscriptions) || const DeepCollectionEquality().equals(other.cpeAppSubscriptions, cpeAppSubscriptions)));
  }

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(profileOsdLang) ^
      const DeepCollectionEquality().hash(profileAgeLock) ^
      const DeepCollectionEquality().hash(profileAudioLang) ^
      const DeepCollectionEquality().hash(profileAudioDescription) ^
      const DeepCollectionEquality().hash(profileSignLanguage) ^
      const DeepCollectionEquality().hash(profileSubControl) ^
      const DeepCollectionEquality().hash(cpeAudioDolbyDigital) ^
      const DeepCollectionEquality().hash(cpeAudioDolbyDigitalMode) ^
      const DeepCollectionEquality().hash(cpeUseHighContrastUI) ^
      const DeepCollectionEquality().hash(profileSubHardOfHearing) ^
      const DeepCollectionEquality().hash(profileSubLang) ^
      const DeepCollectionEquality().hash(profileSurfFavoriteChannels) ^
      const DeepCollectionEquality().hash(profileOnScreenKeyboardMode) ^
      const DeepCollectionEquality().hash(profileRecentlyUsedSettingsItems) ^
      const DeepCollectionEquality().hash(profileRecentlyUsedAppsItems) ^
      const DeepCollectionEquality().hash(profileTipsAndTricks) ^
      const DeepCollectionEquality().hash(profileRecentlyListenedRadios) ^
      const DeepCollectionEquality().hash(profileAccessibleViews) ^
      const DeepCollectionEquality().hash(profileTextToSpeech) ^
      const DeepCollectionEquality().hash(profileTextToSpeechVoice) ^
      const DeepCollectionEquality().hash(profileTextToSpeechSpeed) ^
      const DeepCollectionEquality().hash(profileTextToSpeechVolume) ^
      const DeepCollectionEquality().hash(cpeRecordPaddingBefore) ^
      const DeepCollectionEquality().hash(cpeRecordPaddingAfter) ^
      const DeepCollectionEquality().hash(customerPersonalSuggestions) ^
      const DeepCollectionEquality().hash(customerAdsOptIn) ^
      const DeepCollectionEquality().hash(customerA2aHgoOptIn) ^
      const DeepCollectionEquality().hash(customerA2aStbOptIn) ^
      const DeepCollectionEquality().hash(cpeFactoryResetState) ^
      const DeepCollectionEquality().hash(cpeIsSilentDowngrade) ^
      const DeepCollectionEquality().hash(cpeHdmiDeviceInfo) ^
      const DeepCollectionEquality().hash(cpeHdmiResolution) ^
      const DeepCollectionEquality().hash(cpePrimaryVideoOutput) ^
      const DeepCollectionEquality().hash(cpeAspectRatio) ^
      const DeepCollectionEquality().hash(cpeHdmiColorOutput) ^
      const DeepCollectionEquality().hash(cpe4by3Handling) ^
      const DeepCollectionEquality().hash(cpe16by9Handling) ^
      const DeepCollectionEquality().hash(cpeAutoTvStartup) ^
      const DeepCollectionEquality().hash(cpeVolume) ^
      const DeepCollectionEquality().hash(cpeWifiClientEnabled) ^
      const DeepCollectionEquality().hash(cpeWifiClientSsid) ^
      const DeepCollectionEquality().hash(cpeWifiClientPass) ^
      const DeepCollectionEquality().hash(cpeAutoStandby) ^
      const DeepCollectionEquality().hash(cpeStandByMode) ^
      const DeepCollectionEquality().hash(cpeShowColdStandByMessage) ^
      const DeepCollectionEquality().hash(cpeShowReplayOptInMessage) ^
      const DeepCollectionEquality().hash(cpeFriendlyName) ^
      const DeepCollectionEquality().hash(cpeQuicksetPairedDevicesInfo) ^
      const DeepCollectionEquality().hash(cpeEnableCEC) ^
      const DeepCollectionEquality().hash(cpeOneTouchViewTurnOffPolicy) ^
      const DeepCollectionEquality().hash(cpeUiTestTools) ^
      const DeepCollectionEquality().hash(cpeSpeedTestResults) ^
      const DeepCollectionEquality().hash(cpeLastUseNetflix) ^
      const DeepCollectionEquality().hash(cpePowerCheck) ^
      const DeepCollectionEquality().hash(cpePowerSource) ^
      const DeepCollectionEquality().hash(cpeDefaultPvrStb) ^
      const DeepCollectionEquality().hash(cpeXaBrokerUrl) ^
      const DeepCollectionEquality().hash(cpeCcsMessages) ^
      const DeepCollectionEquality().hash(cpeDefaultProfileId) ^
      const DeepCollectionEquality().hash(cpeCcAnalogService) ^
      const DeepCollectionEquality().hash(cpeCcDigitalService) ^
      const DeepCollectionEquality().hash(cpeMatchFrameRate) ^
      const DeepCollectionEquality().hash(cpeAskPurchasePin) ^
      const DeepCollectionEquality().hash(cpeAskRecPlayPin) ^
      const DeepCollectionEquality().hash(cpeLockedApps) ^
      const DeepCollectionEquality().hash(customerCustomerId) ^
      const DeepCollectionEquality().hash(customerIsSuspended) ^
      const DeepCollectionEquality().hash(customerIsAdultPinUsed) ^
      const DeepCollectionEquality().hash(customerIsFtiPassed) ^
      const DeepCollectionEquality().hash(customerAppsOptIn) ^
      const DeepCollectionEquality().hash(customerReplayOptIn) ^
      const DeepCollectionEquality().hash(customerReplayOptInTime) ^
      const DeepCollectionEquality().hash(customerDefaultHhStb) ^
      const DeepCollectionEquality().hash(customerCityId) ^
      const DeepCollectionEquality().hash(customerDeleteRecordingReminder) ^
      const DeepCollectionEquality().hash(customerAutoDeleteFunction) ^
      const DeepCollectionEquality().hash(customerRecordingRetentionPeriod) ^
      const DeepCollectionEquality().hash(customerZipCode) ^
      const DeepCollectionEquality().hash(cpeAdsOptInShownForRelease) ^
      const DeepCollectionEquality().hash(cpeDisplayedStandByMessageCount) ^
      const DeepCollectionEquality().hash(cpeSlowStandByCyclesCount) ^
      const DeepCollectionEquality().hash(cpeNetflixRailCache) ^
      const DeepCollectionEquality().hash(cpeNetflixToken) ^
      const DeepCollectionEquality().hash(cpeNetflixVdid) ^
      const DeepCollectionEquality().hash(cpeAudioDelayDD) ^
      const DeepCollectionEquality().hash(cpeAudioDelayPCM) ^
      const DeepCollectionEquality().hash(cpeIsAlexaLinked) ^
      const DeepCollectionEquality().hash(cpeLastUsedBrandedScreenKey) ^
      const DeepCollectionEquality().hash(cpeAppSubscriptions) ^
      runtimeType.hashCode;
}

extension $SettingResponseExtension on SettingResponse {
  SettingResponse copyWith(
      {enums.SettingResponseProfileOsdLang? profileOsdLang,
      double? profileAgeLock,
      enums.SettingResponseProfileAudioLang? profileAudioLang,
      bool? profileAudioDescription,
      bool? profileSignLanguage,
      bool? profileSubControl,
      bool? cpeAudioDolbyDigital,
      enums.SettingResponseCpeAudioDolbyDigitalMode? cpeAudioDolbyDigitalMode,
      bool? cpeUseHighContrastUI,
      bool? profileSubHardOfHearing,
      enums.SettingResponseProfileSubLang? profileSubLang,
      bool? profileSurfFavoriteChannels,
      enums.SettingResponseProfileOnScreenKeyboardMode?
          profileOnScreenKeyboardMode,
      List<String>? profileRecentlyUsedSettingsItems,
      List<String>? profileRecentlyUsedAppsItems,
      SettingResponse$ProfileTipsAndTricks? profileTipsAndTricks,
      List<String>? profileRecentlyListenedRadios,
      List<String>? profileAccessibleViews,
      bool? profileTextToSpeech,
      Map<String, dynamic>? profileTextToSpeechVoice,
      enums.SettingResponseProfileTextToSpeechSpeed? profileTextToSpeechSpeed,
      enums.SettingResponseProfileTextToSpeechVolume? profileTextToSpeechVolume,
      double? cpeRecordPaddingBefore,
      double? cpeRecordPaddingAfter,
      bool? customerPersonalSuggestions,
      bool? customerAdsOptIn,
      bool? customerA2aHgoOptIn,
      bool? customerA2aStbOptIn,
      enums.SettingResponseCpeFactoryResetState? cpeFactoryResetState,
      bool? cpeIsSilentDowngrade,
      SettingResponse$CpeHdmiDeviceInfo? cpeHdmiDeviceInfo,
      enums.SettingResponseCpeHdmiResolution? cpeHdmiResolution,
      enums.SettingResponseCpePrimaryVideoOutput? cpePrimaryVideoOutput,
      enums.SettingResponseCpeAspectRatio? cpeAspectRatio,
      enums.SettingResponseCpeHdmiColorOutput? cpeHdmiColorOutput,
      enums.SettingResponseCpe4by3Handling? cpe4by3Handling,
      enums.SettingResponseCpe16by9Handling? cpe16by9Handling,
      bool? cpeAutoTvStartup,
      double? cpeVolume,
      bool? cpeWifiClientEnabled,
      String? cpeWifiClientSsid,
      String? cpeWifiClientPass,
      double? cpeAutoStandby,
      enums.SettingResponseCpeStandByMode? cpeStandByMode,
      bool? cpeShowColdStandByMessage,
      bool? cpeShowReplayOptInMessage,
      String? cpeFriendlyName,
      SettingResponse$CpeQuicksetPairedDevicesInfo?
          cpeQuicksetPairedDevicesInfo,
      bool? cpeEnableCEC,
      bool? cpeOneTouchViewTurnOffPolicy,
      bool? cpeUiTestTools,
      List<SettingResponse$CpeSpeedTestResults>? cpeSpeedTestResults,
      double? cpeLastUseNetflix,
      enums.SettingResponseCpePowerCheck? cpePowerCheck,
      enums.SettingResponseCpePowerSource? cpePowerSource,
      String? cpeDefaultPvrStb,
      String? cpeXaBrokerUrl,
      List<String>? cpeCcsMessages,
      String? cpeDefaultProfileId,
      enums.SettingResponseCpeCcAnalogService? cpeCcAnalogService,
      enums.SettingResponseCpeCcDigitalService? cpeCcDigitalService,
      bool? cpeMatchFrameRate,
      bool? cpeAskPurchasePin,
      bool? cpeAskRecPlayPin,
      List<String>? cpeLockedApps,
      String? customerCustomerId,
      bool? customerIsSuspended,
      bool? customerIsAdultPinUsed,
      bool? customerIsFtiPassed,
      bool? customerAppsOptIn,
      bool? customerReplayOptIn,
      double? customerReplayOptInTime,
      String? customerDefaultHhStb,
      String? customerCityId,
      bool? customerDeleteRecordingReminder,
      bool? customerAutoDeleteFunction,
      double? customerRecordingRetentionPeriod,
      String? customerZipCode,
      String? cpeAdsOptInShownForRelease,
      int? cpeDisplayedStandByMessageCount,
      int? cpeSlowStandByCyclesCount,
      String? cpeNetflixRailCache,
      String? cpeNetflixToken,
      String? cpeNetflixVdid,
      int? cpeAudioDelayDD,
      int? cpeAudioDelayPCM,
      bool? cpeIsAlexaLinked,
      String? cpeLastUsedBrandedScreenKey,
      Map<String, dynamic>? cpeAppSubscriptions}) {
    return SettingResponse(
        profileOsdLang: profileOsdLang ?? this.profileOsdLang,
        profileAgeLock: profileAgeLock ?? this.profileAgeLock,
        profileAudioLang: profileAudioLang ?? this.profileAudioLang,
        profileAudioDescription:
            profileAudioDescription ?? this.profileAudioDescription,
        profileSignLanguage: profileSignLanguage ?? this.profileSignLanguage,
        profileSubControl: profileSubControl ?? this.profileSubControl,
        cpeAudioDolbyDigital: cpeAudioDolbyDigital ?? this.cpeAudioDolbyDigital,
        cpeAudioDolbyDigitalMode:
            cpeAudioDolbyDigitalMode ?? this.cpeAudioDolbyDigitalMode,
        cpeUseHighContrastUI: cpeUseHighContrastUI ?? this.cpeUseHighContrastUI,
        profileSubHardOfHearing:
            profileSubHardOfHearing ?? this.profileSubHardOfHearing,
        profileSubLang: profileSubLang ?? this.profileSubLang,
        profileSurfFavoriteChannels:
            profileSurfFavoriteChannels ?? this.profileSurfFavoriteChannels,
        profileOnScreenKeyboardMode:
            profileOnScreenKeyboardMode ?? this.profileOnScreenKeyboardMode,
        profileRecentlyUsedSettingsItems: profileRecentlyUsedSettingsItems ??
            this.profileRecentlyUsedSettingsItems,
        profileRecentlyUsedAppsItems:
            profileRecentlyUsedAppsItems ?? this.profileRecentlyUsedAppsItems,
        profileTipsAndTricks: profileTipsAndTricks ?? this.profileTipsAndTricks,
        profileRecentlyListenedRadios:
            profileRecentlyListenedRadios ?? this.profileRecentlyListenedRadios,
        profileAccessibleViews:
            profileAccessibleViews ?? this.profileAccessibleViews,
        profileTextToSpeech: profileTextToSpeech ?? this.profileTextToSpeech,
        profileTextToSpeechVoice:
            profileTextToSpeechVoice ?? this.profileTextToSpeechVoice,
        profileTextToSpeechSpeed:
            profileTextToSpeechSpeed ?? this.profileTextToSpeechSpeed,
        profileTextToSpeechVolume:
            profileTextToSpeechVolume ?? this.profileTextToSpeechVolume,
        cpeRecordPaddingBefore:
            cpeRecordPaddingBefore ?? this.cpeRecordPaddingBefore,
        cpeRecordPaddingAfter:
            cpeRecordPaddingAfter ?? this.cpeRecordPaddingAfter,
        customerPersonalSuggestions:
            customerPersonalSuggestions ?? this.customerPersonalSuggestions,
        customerAdsOptIn: customerAdsOptIn ?? this.customerAdsOptIn,
        customerA2aHgoOptIn: customerA2aHgoOptIn ?? this.customerA2aHgoOptIn,
        customerA2aStbOptIn: customerA2aStbOptIn ?? this.customerA2aStbOptIn,
        cpeFactoryResetState: cpeFactoryResetState ?? this.cpeFactoryResetState,
        cpeIsSilentDowngrade: cpeIsSilentDowngrade ?? this.cpeIsSilentDowngrade,
        cpeHdmiDeviceInfo: cpeHdmiDeviceInfo ?? this.cpeHdmiDeviceInfo,
        cpeHdmiResolution: cpeHdmiResolution ?? this.cpeHdmiResolution,
        cpePrimaryVideoOutput:
            cpePrimaryVideoOutput ?? this.cpePrimaryVideoOutput,
        cpeAspectRatio: cpeAspectRatio ?? this.cpeAspectRatio,
        cpeHdmiColorOutput: cpeHdmiColorOutput ?? this.cpeHdmiColorOutput,
        cpe4by3Handling: cpe4by3Handling ?? this.cpe4by3Handling,
        cpe16by9Handling: cpe16by9Handling ?? this.cpe16by9Handling,
        cpeAutoTvStartup: cpeAutoTvStartup ?? this.cpeAutoTvStartup,
        cpeVolume: cpeVolume ?? this.cpeVolume,
        cpeWifiClientEnabled: cpeWifiClientEnabled ?? this.cpeWifiClientEnabled,
        cpeWifiClientSsid: cpeWifiClientSsid ?? this.cpeWifiClientSsid,
        cpeWifiClientPass: cpeWifiClientPass ?? this.cpeWifiClientPass,
        cpeAutoStandby: cpeAutoStandby ?? this.cpeAutoStandby,
        cpeStandByMode: cpeStandByMode ?? this.cpeStandByMode,
        cpeShowColdStandByMessage:
            cpeShowColdStandByMessage ?? this.cpeShowColdStandByMessage,
        cpeShowReplayOptInMessage:
            cpeShowReplayOptInMessage ?? this.cpeShowReplayOptInMessage,
        cpeFriendlyName: cpeFriendlyName ?? this.cpeFriendlyName,
        cpeQuicksetPairedDevicesInfo:
            cpeQuicksetPairedDevicesInfo ?? this.cpeQuicksetPairedDevicesInfo,
        cpeEnableCEC: cpeEnableCEC ?? this.cpeEnableCEC,
        cpeOneTouchViewTurnOffPolicy:
            cpeOneTouchViewTurnOffPolicy ?? this.cpeOneTouchViewTurnOffPolicy,
        cpeUiTestTools: cpeUiTestTools ?? this.cpeUiTestTools,
        cpeSpeedTestResults: cpeSpeedTestResults ?? this.cpeSpeedTestResults,
        cpeLastUseNetflix: cpeLastUseNetflix ?? this.cpeLastUseNetflix,
        cpePowerCheck: cpePowerCheck ?? this.cpePowerCheck,
        cpePowerSource: cpePowerSource ?? this.cpePowerSource,
        cpeDefaultPvrStb: cpeDefaultPvrStb ?? this.cpeDefaultPvrStb,
        cpeXaBrokerUrl: cpeXaBrokerUrl ?? this.cpeXaBrokerUrl,
        cpeCcsMessages: cpeCcsMessages ?? this.cpeCcsMessages,
        cpeDefaultProfileId: cpeDefaultProfileId ?? this.cpeDefaultProfileId,
        cpeCcAnalogService: cpeCcAnalogService ?? this.cpeCcAnalogService,
        cpeCcDigitalService: cpeCcDigitalService ?? this.cpeCcDigitalService,
        cpeMatchFrameRate: cpeMatchFrameRate ?? this.cpeMatchFrameRate,
        cpeAskPurchasePin: cpeAskPurchasePin ?? this.cpeAskPurchasePin,
        cpeAskRecPlayPin: cpeAskRecPlayPin ?? this.cpeAskRecPlayPin,
        cpeLockedApps: cpeLockedApps ?? this.cpeLockedApps,
        customerCustomerId: customerCustomerId ?? this.customerCustomerId,
        customerIsSuspended: customerIsSuspended ?? this.customerIsSuspended,
        customerIsAdultPinUsed:
            customerIsAdultPinUsed ?? this.customerIsAdultPinUsed,
        customerIsFtiPassed: customerIsFtiPassed ?? this.customerIsFtiPassed,
        customerAppsOptIn: customerAppsOptIn ?? this.customerAppsOptIn,
        customerReplayOptIn: customerReplayOptIn ?? this.customerReplayOptIn,
        customerReplayOptInTime:
            customerReplayOptInTime ?? this.customerReplayOptInTime,
        customerDefaultHhStb: customerDefaultHhStb ?? this.customerDefaultHhStb,
        customerCityId: customerCityId ?? this.customerCityId,
        customerDeleteRecordingReminder: customerDeleteRecordingReminder ??
            this.customerDeleteRecordingReminder,
        customerAutoDeleteFunction:
            customerAutoDeleteFunction ?? this.customerAutoDeleteFunction,
        customerRecordingRetentionPeriod: customerRecordingRetentionPeriod ??
            this.customerRecordingRetentionPeriod,
        customerZipCode: customerZipCode ?? this.customerZipCode,
        cpeAdsOptInShownForRelease:
            cpeAdsOptInShownForRelease ?? this.cpeAdsOptInShownForRelease,
        cpeDisplayedStandByMessageCount: cpeDisplayedStandByMessageCount ??
            this.cpeDisplayedStandByMessageCount,
        cpeSlowStandByCyclesCount:
            cpeSlowStandByCyclesCount ?? this.cpeSlowStandByCyclesCount,
        cpeNetflixRailCache: cpeNetflixRailCache ?? this.cpeNetflixRailCache,
        cpeNetflixToken: cpeNetflixToken ?? this.cpeNetflixToken,
        cpeNetflixVdid: cpeNetflixVdid ?? this.cpeNetflixVdid,
        cpeAudioDelayDD: cpeAudioDelayDD ?? this.cpeAudioDelayDD,
        cpeAudioDelayPCM: cpeAudioDelayPCM ?? this.cpeAudioDelayPCM,
        cpeIsAlexaLinked: cpeIsAlexaLinked ?? this.cpeIsAlexaLinked,
        cpeLastUsedBrandedScreenKey:
            cpeLastUsedBrandedScreenKey ?? this.cpeLastUsedBrandedScreenKey,
        cpeAppSubscriptions: cpeAppSubscriptions ?? this.cpeAppSubscriptions);
  }
}

@JsonSerializable(explicitToJson: true)
class ErrorResponse {
  ErrorResponse({
    required this.message,
  });

  factory ErrorResponse.fromJson(Map<String, dynamic> json) =>
      _$ErrorResponseFromJson(json);

  @JsonKey(name: 'message', includeIfNull: false, defaultValue: '')
  final String message;
  static const fromJsonFactory = _$ErrorResponseFromJson;
  static const toJsonFactory = _$ErrorResponseToJson;
  Map<String, dynamic> toJson() => _$ErrorResponseToJson(this);

  @override
  String toString() => jsonEncode(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is ErrorResponse &&
            (identical(other.message, message) ||
                const DeepCollectionEquality().equals(other.message, message)));
  }

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(message) ^ runtimeType.hashCode;
}

extension $ErrorResponseExtension on ErrorResponse {
  ErrorResponse copyWith({String? message}) {
    return ErrorResponse(message: message ?? this.message);
  }
}

@JsonSerializable(explicitToJson: true)
class OnChangeEvent {
  OnChangeEvent({
    required this.key,
    this.newValue,
    this.oldValue,
  });

  factory OnChangeEvent.fromJson(Map<String, dynamic> json) =>
      _$OnChangeEventFromJson(json);

  @JsonKey(name: 'key', includeIfNull: false, defaultValue: '')
  final String key;
  @JsonKey(name: 'newValue', includeIfNull: false)
  final Any? newValue;
  @JsonKey(name: 'oldValue', includeIfNull: false)
  final Any? oldValue;
  static const fromJsonFactory = _$OnChangeEventFromJson;
  static const toJsonFactory = _$OnChangeEventToJson;
  Map<String, dynamic> toJson() => _$OnChangeEventToJson(this);

  @override
  String toString() => jsonEncode(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is OnChangeEvent &&
            (identical(other.key, key) ||
                const DeepCollectionEquality().equals(other.key, key)) &&
            (identical(other.newValue, newValue) ||
                const DeepCollectionEquality()
                    .equals(other.newValue, newValue)) &&
            (identical(other.oldValue, oldValue) ||
                const DeepCollectionEquality()
                    .equals(other.oldValue, oldValue)));
  }

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(key) ^
      const DeepCollectionEquality().hash(newValue) ^
      const DeepCollectionEquality().hash(oldValue) ^
      runtimeType.hashCode;
}

extension $OnChangeEventExtension on OnChangeEvent {
  OnChangeEvent copyWith({String? key, Any? newValue, Any? oldValue}) {
    return OnChangeEvent(
        key: key ?? this.key,
        newValue: newValue ?? this.newValue,
        oldValue: oldValue ?? this.oldValue);
  }
}

@JsonSerializable(explicitToJson: true)
class SettingResponse$ProfileTipsAndTricks {
  SettingResponse$ProfileTipsAndTricks({
    required this.ids,
    required this.timestamps,
    this.counters,
  });

  factory SettingResponse$ProfileTipsAndTricks.fromJson(
          Map<String, dynamic> json) =>
      _$SettingResponse$ProfileTipsAndTricksFromJson(json);

  @JsonKey(name: 'ids', includeIfNull: false, defaultValue: <String>[])
  final List<String> ids;
  @JsonKey(name: 'timestamps', includeIfNull: false, defaultValue: <double>[])
  final List<double> timestamps;
  @JsonKey(name: 'counters', includeIfNull: false)
  final Map<String, dynamic>? counters;
  static const fromJsonFactory = _$SettingResponse$ProfileTipsAndTricksFromJson;
  static const toJsonFactory = _$SettingResponse$ProfileTipsAndTricksToJson;
  Map<String, dynamic> toJson() =>
      _$SettingResponse$ProfileTipsAndTricksToJson(this);

  @override
  String toString() => jsonEncode(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is SettingResponse$ProfileTipsAndTricks &&
            (identical(other.ids, ids) ||
                const DeepCollectionEquality().equals(other.ids, ids)) &&
            (identical(other.timestamps, timestamps) ||
                const DeepCollectionEquality()
                    .equals(other.timestamps, timestamps)) &&
            (identical(other.counters, counters) ||
                const DeepCollectionEquality()
                    .equals(other.counters, counters)));
  }

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(ids) ^
      const DeepCollectionEquality().hash(timestamps) ^
      const DeepCollectionEquality().hash(counters) ^
      runtimeType.hashCode;
}

extension $SettingResponse$ProfileTipsAndTricksExtension
    on SettingResponse$ProfileTipsAndTricks {
  SettingResponse$ProfileTipsAndTricks copyWith(
      {List<String>? ids,
      List<double>? timestamps,
      Map<String, dynamic>? counters}) {
    return SettingResponse$ProfileTipsAndTricks(
        ids: ids ?? this.ids,
        timestamps: timestamps ?? this.timestamps,
        counters: counters ?? this.counters);
  }
}

@JsonSerializable(explicitToJson: true)
class SettingResponse$CpeHdmiDeviceInfo {
  SettingResponse$CpeHdmiDeviceInfo({
    this.maxSupportedResolution,
  });

  factory SettingResponse$CpeHdmiDeviceInfo.fromJson(
          Map<String, dynamic> json) =>
      _$SettingResponse$CpeHdmiDeviceInfoFromJson(json);

  @JsonKey(
      name: 'maxSupportedResolution', includeIfNull: false, defaultValue: '')
  final String? maxSupportedResolution;
  static const fromJsonFactory = _$SettingResponse$CpeHdmiDeviceInfoFromJson;
  static const toJsonFactory = _$SettingResponse$CpeHdmiDeviceInfoToJson;
  Map<String, dynamic> toJson() =>
      _$SettingResponse$CpeHdmiDeviceInfoToJson(this);

  @override
  String toString() => jsonEncode(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is SettingResponse$CpeHdmiDeviceInfo &&
            (identical(other.maxSupportedResolution, maxSupportedResolution) ||
                const DeepCollectionEquality().equals(
                    other.maxSupportedResolution, maxSupportedResolution)));
  }

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(maxSupportedResolution) ^
      runtimeType.hashCode;
}

extension $SettingResponse$CpeHdmiDeviceInfoExtension
    on SettingResponse$CpeHdmiDeviceInfo {
  SettingResponse$CpeHdmiDeviceInfo copyWith({String? maxSupportedResolution}) {
    return SettingResponse$CpeHdmiDeviceInfo(
        maxSupportedResolution:
            maxSupportedResolution ?? this.maxSupportedResolution);
  }
}

@JsonSerializable(explicitToJson: true)
class SettingResponse$CpeQuicksetPairedDevicesInfo {
  SettingResponse$CpeQuicksetPairedDevicesInfo({
    required this.physicalAddress,
    required this.edid,
    required this.volumeLock,
    this.volumeLockMethod,
    required this.tv,
    required this.amp,
    this.stats,
  });

  factory SettingResponse$CpeQuicksetPairedDevicesInfo.fromJson(
          Map<String, dynamic> json) =>
      _$SettingResponse$CpeQuicksetPairedDevicesInfoFromJson(json);

  @JsonKey(name: 'physicalAddress', includeIfNull: false, defaultValue: '')
  final String physicalAddress;
  @JsonKey(name: 'edid', includeIfNull: false, defaultValue: '')
  final String edid;
  @JsonKey(name: 'volumeLock', includeIfNull: false)
  final int volumeLock;
  @JsonKey(name: 'volumeLockMethod', includeIfNull: false, defaultValue: '')
  final String? volumeLockMethod;
  @JsonKey(name: 'tv', includeIfNull: false)
  final SettingResponse$CpeQuicksetPairedDevicesInfo$Tv tv;
  @JsonKey(name: 'amp', includeIfNull: false)
  final SettingResponse$CpeQuicksetPairedDevicesInfo$Amp amp;
  @JsonKey(name: 'stats', includeIfNull: false)
  final SettingResponse$CpeQuicksetPairedDevicesInfo$Stats? stats;
  static const fromJsonFactory =
      _$SettingResponse$CpeQuicksetPairedDevicesInfoFromJson;
  static const toJsonFactory =
      _$SettingResponse$CpeQuicksetPairedDevicesInfoToJson;
  Map<String, dynamic> toJson() =>
      _$SettingResponse$CpeQuicksetPairedDevicesInfoToJson(this);

  @override
  String toString() => jsonEncode(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is SettingResponse$CpeQuicksetPairedDevicesInfo &&
            (identical(other.physicalAddress, physicalAddress) ||
                const DeepCollectionEquality()
                    .equals(other.physicalAddress, physicalAddress)) &&
            (identical(other.edid, edid) ||
                const DeepCollectionEquality().equals(other.edid, edid)) &&
            (identical(other.volumeLock, volumeLock) ||
                const DeepCollectionEquality()
                    .equals(other.volumeLock, volumeLock)) &&
            (identical(other.volumeLockMethod, volumeLockMethod) ||
                const DeepCollectionEquality()
                    .equals(other.volumeLockMethod, volumeLockMethod)) &&
            (identical(other.tv, tv) ||
                const DeepCollectionEquality().equals(other.tv, tv)) &&
            (identical(other.amp, amp) ||
                const DeepCollectionEquality().equals(other.amp, amp)) &&
            (identical(other.stats, stats) ||
                const DeepCollectionEquality().equals(other.stats, stats)));
  }

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(physicalAddress) ^
      const DeepCollectionEquality().hash(edid) ^
      const DeepCollectionEquality().hash(volumeLock) ^
      const DeepCollectionEquality().hash(volumeLockMethod) ^
      const DeepCollectionEquality().hash(tv) ^
      const DeepCollectionEquality().hash(amp) ^
      const DeepCollectionEquality().hash(stats) ^
      runtimeType.hashCode;
}

extension $SettingResponse$CpeQuicksetPairedDevicesInfoExtension
    on SettingResponse$CpeQuicksetPairedDevicesInfo {
  SettingResponse$CpeQuicksetPairedDevicesInfo copyWith(
      {String? physicalAddress,
      String? edid,
      int? volumeLock,
      String? volumeLockMethod,
      SettingResponse$CpeQuicksetPairedDevicesInfo$Tv? tv,
      SettingResponse$CpeQuicksetPairedDevicesInfo$Amp? amp,
      SettingResponse$CpeQuicksetPairedDevicesInfo$Stats? stats}) {
    return SettingResponse$CpeQuicksetPairedDevicesInfo(
        physicalAddress: physicalAddress ?? this.physicalAddress,
        edid: edid ?? this.edid,
        volumeLock: volumeLock ?? this.volumeLock,
        volumeLockMethod: volumeLockMethod ?? this.volumeLockMethod,
        tv: tv ?? this.tv,
        amp: amp ?? this.amp,
        stats: stats ?? this.stats);
  }
}

typedef SettingResponse$CpeSpeedTestResults
    = List<SettingResponse$CpeSpeedTestResults$Item>;

@JsonSerializable(explicitToJson: true)
class SettingResponse$CpeSpeedTestResults$Item {
  SettingResponse$CpeSpeedTestResults$Item({
    this.timestamp,
    this.interface,
    this.downstreamBitrate,
    this.upstreamBitrate,
  });

  factory SettingResponse$CpeSpeedTestResults$Item.fromJson(
          Map<String, dynamic> json) =>
      _$SettingResponse$CpeSpeedTestResults$ItemFromJson(json);

  @JsonKey(name: 'timestamp', includeIfNull: false)
  final double? timestamp;
  @JsonKey(name: 'interface', includeIfNull: false, defaultValue: '')
  final String? interface;
  @JsonKey(name: 'downstreamBitrate', includeIfNull: false)
  final double? downstreamBitrate;
  @JsonKey(name: 'upstreamBitrate', includeIfNull: false)
  final double? upstreamBitrate;
  static const fromJsonFactory =
      _$SettingResponse$CpeSpeedTestResults$ItemFromJson;
  static const toJsonFactory = _$SettingResponse$CpeSpeedTestResults$ItemToJson;
  Map<String, dynamic> toJson() =>
      _$SettingResponse$CpeSpeedTestResults$ItemToJson(this);

  @override
  String toString() => jsonEncode(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is SettingResponse$CpeSpeedTestResults$Item &&
            (identical(other.timestamp, timestamp) ||
                const DeepCollectionEquality()
                    .equals(other.timestamp, timestamp)) &&
            (identical(other.interface, interface) ||
                const DeepCollectionEquality()
                    .equals(other.interface, interface)) &&
            (identical(other.downstreamBitrate, downstreamBitrate) ||
                const DeepCollectionEquality()
                    .equals(other.downstreamBitrate, downstreamBitrate)) &&
            (identical(other.upstreamBitrate, upstreamBitrate) ||
                const DeepCollectionEquality()
                    .equals(other.upstreamBitrate, upstreamBitrate)));
  }

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(timestamp) ^
      const DeepCollectionEquality().hash(interface) ^
      const DeepCollectionEquality().hash(downstreamBitrate) ^
      const DeepCollectionEquality().hash(upstreamBitrate) ^
      runtimeType.hashCode;
}

extension $SettingResponse$CpeSpeedTestResults$ItemExtension
    on SettingResponse$CpeSpeedTestResults$Item {
  SettingResponse$CpeSpeedTestResults$Item copyWith(
      {double? timestamp,
      String? interface,
      double? downstreamBitrate,
      double? upstreamBitrate}) {
    return SettingResponse$CpeSpeedTestResults$Item(
        timestamp: timestamp ?? this.timestamp,
        interface: interface ?? this.interface,
        downstreamBitrate: downstreamBitrate ?? this.downstreamBitrate,
        upstreamBitrate: upstreamBitrate ?? this.upstreamBitrate);
  }
}

@JsonSerializable(explicitToJson: true)
class SettingResponse$CpeQuicksetPairedDevicesInfo$Tv {
  SettingResponse$CpeQuicksetPairedDevicesInfo$Tv({
    required this.brand,
    required this.model,
    required this.vendorId,
    required this.osd,
    required this.codeset,
    this.codesetBlob,
    required this.discreteCodeset,
    this.discreteCodesetBlob,
    required this.controlRule,
    required this.cecCmdDataPowerOn,
    required this.cecCmdDataPowerOff,
    required this.cecCmdDataInputSelect,
    required this.isPaired,
    required this.pairingMethod,
  });

  factory SettingResponse$CpeQuicksetPairedDevicesInfo$Tv.fromJson(
          Map<String, dynamic> json) =>
      _$SettingResponse$CpeQuicksetPairedDevicesInfo$TvFromJson(json);

  @JsonKey(name: 'brand', includeIfNull: false, defaultValue: '')
  final String brand;
  @JsonKey(name: 'model', includeIfNull: false, defaultValue: '')
  final String model;
  @JsonKey(name: 'vendorId', includeIfNull: false, defaultValue: '')
  final String vendorId;
  @JsonKey(name: 'osd', includeIfNull: false, defaultValue: '')
  final String osd;
  @JsonKey(name: 'codeset', includeIfNull: false, defaultValue: '')
  final String codeset;
  @JsonKey(name: 'codesetBlob', includeIfNull: false, defaultValue: '')
  final String? codesetBlob;
  @JsonKey(name: 'discreteCodeset', includeIfNull: false, defaultValue: '')
  final String discreteCodeset;
  @JsonKey(name: 'discreteCodesetBlob', includeIfNull: false, defaultValue: '')
  final String? discreteCodesetBlob;
  @JsonKey(name: 'controlRule', includeIfNull: false, defaultValue: '')
  final String controlRule;
  @JsonKey(name: 'cecCmdDataPowerOn', includeIfNull: false, defaultValue: '')
  final String cecCmdDataPowerOn;
  @JsonKey(name: 'cecCmdDataPowerOff', includeIfNull: false, defaultValue: '')
  final String cecCmdDataPowerOff;
  @JsonKey(
      name: 'cecCmdDataInputSelect', includeIfNull: false, defaultValue: '')
  final String cecCmdDataInputSelect;
  @JsonKey(name: 'isPaired', includeIfNull: false)
  final bool isPaired;
  @JsonKey(name: 'pairingMethod', includeIfNull: false, defaultValue: '')
  final String pairingMethod;
  static const fromJsonFactory =
      _$SettingResponse$CpeQuicksetPairedDevicesInfo$TvFromJson;
  static const toJsonFactory =
      _$SettingResponse$CpeQuicksetPairedDevicesInfo$TvToJson;
  Map<String, dynamic> toJson() =>
      _$SettingResponse$CpeQuicksetPairedDevicesInfo$TvToJson(this);

  @override
  String toString() => jsonEncode(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is SettingResponse$CpeQuicksetPairedDevicesInfo$Tv &&
            (identical(other.brand, brand) ||
                const DeepCollectionEquality().equals(other.brand, brand)) &&
            (identical(other.model, model) ||
                const DeepCollectionEquality().equals(other.model, model)) &&
            (identical(other.vendorId, vendorId) ||
                const DeepCollectionEquality()
                    .equals(other.vendorId, vendorId)) &&
            (identical(other.osd, osd) ||
                const DeepCollectionEquality().equals(other.osd, osd)) &&
            (identical(other.codeset, codeset) ||
                const DeepCollectionEquality()
                    .equals(other.codeset, codeset)) &&
            (identical(other.codesetBlob, codesetBlob) ||
                const DeepCollectionEquality()
                    .equals(other.codesetBlob, codesetBlob)) &&
            (identical(other.discreteCodeset, discreteCodeset) ||
                const DeepCollectionEquality()
                    .equals(other.discreteCodeset, discreteCodeset)) &&
            (identical(other.discreteCodesetBlob, discreteCodesetBlob) ||
                const DeepCollectionEquality()
                    .equals(other.discreteCodesetBlob, discreteCodesetBlob)) &&
            (identical(other.controlRule, controlRule) ||
                const DeepCollectionEquality()
                    .equals(other.controlRule, controlRule)) &&
            (identical(other.cecCmdDataPowerOn, cecCmdDataPowerOn) ||
                const DeepCollectionEquality()
                    .equals(other.cecCmdDataPowerOn, cecCmdDataPowerOn)) &&
            (identical(other.cecCmdDataPowerOff, cecCmdDataPowerOff) ||
                const DeepCollectionEquality()
                    .equals(other.cecCmdDataPowerOff, cecCmdDataPowerOff)) &&
            (identical(other.cecCmdDataInputSelect, cecCmdDataInputSelect) ||
                const DeepCollectionEquality().equals(
                    other.cecCmdDataInputSelect, cecCmdDataInputSelect)) &&
            (identical(other.isPaired, isPaired) ||
                const DeepCollectionEquality()
                    .equals(other.isPaired, isPaired)) &&
            (identical(other.pairingMethod, pairingMethod) ||
                const DeepCollectionEquality()
                    .equals(other.pairingMethod, pairingMethod)));
  }

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(brand) ^
      const DeepCollectionEquality().hash(model) ^
      const DeepCollectionEquality().hash(vendorId) ^
      const DeepCollectionEquality().hash(osd) ^
      const DeepCollectionEquality().hash(codeset) ^
      const DeepCollectionEquality().hash(codesetBlob) ^
      const DeepCollectionEquality().hash(discreteCodeset) ^
      const DeepCollectionEquality().hash(discreteCodesetBlob) ^
      const DeepCollectionEquality().hash(controlRule) ^
      const DeepCollectionEquality().hash(cecCmdDataPowerOn) ^
      const DeepCollectionEquality().hash(cecCmdDataPowerOff) ^
      const DeepCollectionEquality().hash(cecCmdDataInputSelect) ^
      const DeepCollectionEquality().hash(isPaired) ^
      const DeepCollectionEquality().hash(pairingMethod) ^
      runtimeType.hashCode;
}

extension $SettingResponse$CpeQuicksetPairedDevicesInfo$TvExtension
    on SettingResponse$CpeQuicksetPairedDevicesInfo$Tv {
  SettingResponse$CpeQuicksetPairedDevicesInfo$Tv copyWith(
      {String? brand,
      String? model,
      String? vendorId,
      String? osd,
      String? codeset,
      String? codesetBlob,
      String? discreteCodeset,
      String? discreteCodesetBlob,
      String? controlRule,
      String? cecCmdDataPowerOn,
      String? cecCmdDataPowerOff,
      String? cecCmdDataInputSelect,
      bool? isPaired,
      String? pairingMethod}) {
    return SettingResponse$CpeQuicksetPairedDevicesInfo$Tv(
        brand: brand ?? this.brand,
        model: model ?? this.model,
        vendorId: vendorId ?? this.vendorId,
        osd: osd ?? this.osd,
        codeset: codeset ?? this.codeset,
        codesetBlob: codesetBlob ?? this.codesetBlob,
        discreteCodeset: discreteCodeset ?? this.discreteCodeset,
        discreteCodesetBlob: discreteCodesetBlob ?? this.discreteCodesetBlob,
        controlRule: controlRule ?? this.controlRule,
        cecCmdDataPowerOn: cecCmdDataPowerOn ?? this.cecCmdDataPowerOn,
        cecCmdDataPowerOff: cecCmdDataPowerOff ?? this.cecCmdDataPowerOff,
        cecCmdDataInputSelect:
            cecCmdDataInputSelect ?? this.cecCmdDataInputSelect,
        isPaired: isPaired ?? this.isPaired,
        pairingMethod: pairingMethod ?? this.pairingMethod);
  }
}

@JsonSerializable(explicitToJson: true)
class SettingResponse$CpeQuicksetPairedDevicesInfo$Amp {
  SettingResponse$CpeQuicksetPairedDevicesInfo$Amp({
    required this.brand,
    required this.model,
    required this.vendorId,
    required this.osd,
    required this.codeset,
    this.codesetBlob,
    required this.discreteCodeset,
    this.discreteCodesetBlob,
    required this.controlRule,
    required this.cecCmdDataPowerOn,
    required this.cecCmdDataPowerOff,
    required this.cecCmdDataInputSelect,
    required this.isPaired,
    required this.pairingMethod,
  });

  factory SettingResponse$CpeQuicksetPairedDevicesInfo$Amp.fromJson(
          Map<String, dynamic> json) =>
      _$SettingResponse$CpeQuicksetPairedDevicesInfo$AmpFromJson(json);

  @JsonKey(name: 'brand', includeIfNull: false, defaultValue: '')
  final String brand;
  @JsonKey(name: 'model', includeIfNull: false, defaultValue: '')
  final String model;
  @JsonKey(name: 'vendorId', includeIfNull: false, defaultValue: '')
  final String vendorId;
  @JsonKey(name: 'osd', includeIfNull: false, defaultValue: '')
  final String osd;
  @JsonKey(name: 'codeset', includeIfNull: false, defaultValue: '')
  final String codeset;
  @JsonKey(name: 'codesetBlob', includeIfNull: false, defaultValue: '')
  final String? codesetBlob;
  @JsonKey(name: 'discreteCodeset', includeIfNull: false, defaultValue: '')
  final String discreteCodeset;
  @JsonKey(name: 'discreteCodesetBlob', includeIfNull: false, defaultValue: '')
  final String? discreteCodesetBlob;
  @JsonKey(name: 'controlRule', includeIfNull: false, defaultValue: '')
  final String controlRule;
  @JsonKey(name: 'cecCmdDataPowerOn', includeIfNull: false, defaultValue: '')
  final String cecCmdDataPowerOn;
  @JsonKey(name: 'cecCmdDataPowerOff', includeIfNull: false, defaultValue: '')
  final String cecCmdDataPowerOff;
  @JsonKey(
      name: 'cecCmdDataInputSelect', includeIfNull: false, defaultValue: '')
  final String cecCmdDataInputSelect;
  @JsonKey(name: 'isPaired', includeIfNull: false)
  final bool isPaired;
  @JsonKey(name: 'pairingMethod', includeIfNull: false, defaultValue: '')
  final String pairingMethod;
  static const fromJsonFactory =
      _$SettingResponse$CpeQuicksetPairedDevicesInfo$AmpFromJson;
  static const toJsonFactory =
      _$SettingResponse$CpeQuicksetPairedDevicesInfo$AmpToJson;
  Map<String, dynamic> toJson() =>
      _$SettingResponse$CpeQuicksetPairedDevicesInfo$AmpToJson(this);

  @override
  String toString() => jsonEncode(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is SettingResponse$CpeQuicksetPairedDevicesInfo$Amp &&
            (identical(other.brand, brand) ||
                const DeepCollectionEquality().equals(other.brand, brand)) &&
            (identical(other.model, model) ||
                const DeepCollectionEquality().equals(other.model, model)) &&
            (identical(other.vendorId, vendorId) ||
                const DeepCollectionEquality()
                    .equals(other.vendorId, vendorId)) &&
            (identical(other.osd, osd) ||
                const DeepCollectionEquality().equals(other.osd, osd)) &&
            (identical(other.codeset, codeset) ||
                const DeepCollectionEquality()
                    .equals(other.codeset, codeset)) &&
            (identical(other.codesetBlob, codesetBlob) ||
                const DeepCollectionEquality()
                    .equals(other.codesetBlob, codesetBlob)) &&
            (identical(other.discreteCodeset, discreteCodeset) ||
                const DeepCollectionEquality()
                    .equals(other.discreteCodeset, discreteCodeset)) &&
            (identical(other.discreteCodesetBlob, discreteCodesetBlob) ||
                const DeepCollectionEquality()
                    .equals(other.discreteCodesetBlob, discreteCodesetBlob)) &&
            (identical(other.controlRule, controlRule) ||
                const DeepCollectionEquality()
                    .equals(other.controlRule, controlRule)) &&
            (identical(other.cecCmdDataPowerOn, cecCmdDataPowerOn) ||
                const DeepCollectionEquality()
                    .equals(other.cecCmdDataPowerOn, cecCmdDataPowerOn)) &&
            (identical(other.cecCmdDataPowerOff, cecCmdDataPowerOff) ||
                const DeepCollectionEquality()
                    .equals(other.cecCmdDataPowerOff, cecCmdDataPowerOff)) &&
            (identical(other.cecCmdDataInputSelect, cecCmdDataInputSelect) ||
                const DeepCollectionEquality().equals(
                    other.cecCmdDataInputSelect, cecCmdDataInputSelect)) &&
            (identical(other.isPaired, isPaired) ||
                const DeepCollectionEquality()
                    .equals(other.isPaired, isPaired)) &&
            (identical(other.pairingMethod, pairingMethod) ||
                const DeepCollectionEquality()
                    .equals(other.pairingMethod, pairingMethod)));
  }

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(brand) ^
      const DeepCollectionEquality().hash(model) ^
      const DeepCollectionEquality().hash(vendorId) ^
      const DeepCollectionEquality().hash(osd) ^
      const DeepCollectionEquality().hash(codeset) ^
      const DeepCollectionEquality().hash(codesetBlob) ^
      const DeepCollectionEquality().hash(discreteCodeset) ^
      const DeepCollectionEquality().hash(discreteCodesetBlob) ^
      const DeepCollectionEquality().hash(controlRule) ^
      const DeepCollectionEquality().hash(cecCmdDataPowerOn) ^
      const DeepCollectionEquality().hash(cecCmdDataPowerOff) ^
      const DeepCollectionEquality().hash(cecCmdDataInputSelect) ^
      const DeepCollectionEquality().hash(isPaired) ^
      const DeepCollectionEquality().hash(pairingMethod) ^
      runtimeType.hashCode;
}

extension $SettingResponse$CpeQuicksetPairedDevicesInfo$AmpExtension
    on SettingResponse$CpeQuicksetPairedDevicesInfo$Amp {
  SettingResponse$CpeQuicksetPairedDevicesInfo$Amp copyWith(
      {String? brand,
      String? model,
      String? vendorId,
      String? osd,
      String? codeset,
      String? codesetBlob,
      String? discreteCodeset,
      String? discreteCodesetBlob,
      String? controlRule,
      String? cecCmdDataPowerOn,
      String? cecCmdDataPowerOff,
      String? cecCmdDataInputSelect,
      bool? isPaired,
      String? pairingMethod}) {
    return SettingResponse$CpeQuicksetPairedDevicesInfo$Amp(
        brand: brand ?? this.brand,
        model: model ?? this.model,
        vendorId: vendorId ?? this.vendorId,
        osd: osd ?? this.osd,
        codeset: codeset ?? this.codeset,
        codesetBlob: codesetBlob ?? this.codesetBlob,
        discreteCodeset: discreteCodeset ?? this.discreteCodeset,
        discreteCodesetBlob: discreteCodesetBlob ?? this.discreteCodesetBlob,
        controlRule: controlRule ?? this.controlRule,
        cecCmdDataPowerOn: cecCmdDataPowerOn ?? this.cecCmdDataPowerOn,
        cecCmdDataPowerOff: cecCmdDataPowerOff ?? this.cecCmdDataPowerOff,
        cecCmdDataInputSelect:
            cecCmdDataInputSelect ?? this.cecCmdDataInputSelect,
        isPaired: isPaired ?? this.isPaired,
        pairingMethod: pairingMethod ?? this.pairingMethod);
  }
}

@JsonSerializable(explicitToJson: true)
class SettingResponse$CpeQuicksetPairedDevicesInfo$Stats {
  SettingResponse$CpeQuicksetPairedDevicesInfo$Stats({
    required this.edidDiscoveryCount,
    required this.cecDiscoveryCount,
    required this.createSessionCount,
    required this.autoLookupCount,
    required this.getPickCount,
    required this.getControlRuleCount,
  });

  factory SettingResponse$CpeQuicksetPairedDevicesInfo$Stats.fromJson(
          Map<String, dynamic> json) =>
      _$SettingResponse$CpeQuicksetPairedDevicesInfo$StatsFromJson(json);

  @JsonKey(name: 'edidDiscoveryCount', includeIfNull: false)
  final int edidDiscoveryCount;
  @JsonKey(name: 'cecDiscoveryCount', includeIfNull: false)
  final int cecDiscoveryCount;
  @JsonKey(name: 'createSessionCount', includeIfNull: false)
  final int createSessionCount;
  @JsonKey(name: 'autoLookupCount', includeIfNull: false)
  final int autoLookupCount;
  @JsonKey(name: 'getPickCount', includeIfNull: false)
  final int getPickCount;
  @JsonKey(name: 'getControlRuleCount', includeIfNull: false)
  final int getControlRuleCount;
  static const fromJsonFactory =
      _$SettingResponse$CpeQuicksetPairedDevicesInfo$StatsFromJson;
  static const toJsonFactory =
      _$SettingResponse$CpeQuicksetPairedDevicesInfo$StatsToJson;
  Map<String, dynamic> toJson() =>
      _$SettingResponse$CpeQuicksetPairedDevicesInfo$StatsToJson(this);

  @override
  String toString() => jsonEncode(this);

  @override
  bool operator ==(dynamic other) {
    return identical(this, other) ||
        (other is SettingResponse$CpeQuicksetPairedDevicesInfo$Stats &&
            (identical(other.edidDiscoveryCount, edidDiscoveryCount) ||
                const DeepCollectionEquality()
                    .equals(other.edidDiscoveryCount, edidDiscoveryCount)) &&
            (identical(other.cecDiscoveryCount, cecDiscoveryCount) ||
                const DeepCollectionEquality()
                    .equals(other.cecDiscoveryCount, cecDiscoveryCount)) &&
            (identical(other.createSessionCount, createSessionCount) ||
                const DeepCollectionEquality()
                    .equals(other.createSessionCount, createSessionCount)) &&
            (identical(other.autoLookupCount, autoLookupCount) ||
                const DeepCollectionEquality()
                    .equals(other.autoLookupCount, autoLookupCount)) &&
            (identical(other.getPickCount, getPickCount) ||
                const DeepCollectionEquality()
                    .equals(other.getPickCount, getPickCount)) &&
            (identical(other.getControlRuleCount, getControlRuleCount) ||
                const DeepCollectionEquality()
                    .equals(other.getControlRuleCount, getControlRuleCount)));
  }

  @override
  int get hashCode =>
      const DeepCollectionEquality().hash(edidDiscoveryCount) ^
      const DeepCollectionEquality().hash(cecDiscoveryCount) ^
      const DeepCollectionEquality().hash(createSessionCount) ^
      const DeepCollectionEquality().hash(autoLookupCount) ^
      const DeepCollectionEquality().hash(getPickCount) ^
      const DeepCollectionEquality().hash(getControlRuleCount) ^
      runtimeType.hashCode;
}

extension $SettingResponse$CpeQuicksetPairedDevicesInfo$StatsExtension
    on SettingResponse$CpeQuicksetPairedDevicesInfo$Stats {
  SettingResponse$CpeQuicksetPairedDevicesInfo$Stats copyWith(
      {int? edidDiscoveryCount,
      int? cecDiscoveryCount,
      int? createSessionCount,
      int? autoLookupCount,
      int? getPickCount,
      int? getControlRuleCount}) {
    return SettingResponse$CpeQuicksetPairedDevicesInfo$Stats(
        edidDiscoveryCount: edidDiscoveryCount ?? this.edidDiscoveryCount,
        cecDiscoveryCount: cecDiscoveryCount ?? this.cecDiscoveryCount,
        createSessionCount: createSessionCount ?? this.createSessionCount,
        autoLookupCount: autoLookupCount ?? this.autoLookupCount,
        getPickCount: getPickCount ?? this.getPickCount,
        getControlRuleCount: getControlRuleCount ?? this.getControlRuleCount);
  }
}

String? settingResponseProfileOsdLangToJson(
    enums.SettingResponseProfileOsdLang? settingResponseProfileOsdLang) {
  return enums.$SettingResponseProfileOsdLangMap[settingResponseProfileOsdLang];
}

enums.SettingResponseProfileOsdLang settingResponseProfileOsdLangFromJson(
  Object? settingResponseProfileOsdLang, [
  enums.SettingResponseProfileOsdLang? defaultValue,
]) {
  if (settingResponseProfileOsdLang is String) {
    return enums.$SettingResponseProfileOsdLangMap.entries
        .firstWhere(
            (element) =>
                element.value.toLowerCase() ==
                settingResponseProfileOsdLang.toLowerCase(),
            orElse: () => const MapEntry(
                enums.SettingResponseProfileOsdLang.swaggerGeneratedUnknown,
                ''))
        .key;
  }

  final parsedResult = defaultValue == null
      ? null
      : enums.$SettingResponseProfileOsdLangMap.entries
          .firstWhereOrNull((element) => element.value == defaultValue)
          ?.key;

  return parsedResult ??
      defaultValue ??
      enums.SettingResponseProfileOsdLang.swaggerGeneratedUnknown;
}

List<String> settingResponseProfileOsdLangListToJson(
    List<enums.SettingResponseProfileOsdLang>? settingResponseProfileOsdLang) {
  if (settingResponseProfileOsdLang == null) {
    return [];
  }

  return settingResponseProfileOsdLang
      .map((e) => enums.$SettingResponseProfileOsdLangMap[e]!)
      .toList();
}

List<enums.SettingResponseProfileOsdLang>
    settingResponseProfileOsdLangListFromJson(
  List? settingResponseProfileOsdLang, [
  List<enums.SettingResponseProfileOsdLang>? defaultValue,
]) {
  if (settingResponseProfileOsdLang == null) {
    return defaultValue ?? [];
  }

  return settingResponseProfileOsdLang
      .map((e) => settingResponseProfileOsdLangFromJson(e.toString()))
      .toList();
}

int? settingResponseProfileAgeLockToJson(
    enums.SettingResponseProfileAgeLock? settingResponseProfileAgeLock) {
  return enums.$SettingResponseProfileAgeLockMap[settingResponseProfileAgeLock];
}

enums.SettingResponseProfileAgeLock settingResponseProfileAgeLockFromJson(
  Object? settingResponseProfileAgeLock, [
  enums.SettingResponseProfileAgeLock? defaultValue,
]) {
  if (settingResponseProfileAgeLock is int) {
    return enums.$SettingResponseProfileAgeLockMap.entries
        .firstWhere((element) => element.value == settingResponseProfileAgeLock,
            orElse: () => const MapEntry(
                enums.SettingResponseProfileAgeLock.swaggerGeneratedUnknown, 0))
        .key;
  }

  final parsedResult = defaultValue == null
      ? null
      : enums.$SettingResponseProfileAgeLockMap.entries
          .firstWhereOrNull((element) => element.value == defaultValue)
          ?.key;

  return parsedResult ??
      defaultValue ??
      enums.SettingResponseProfileAgeLock.swaggerGeneratedUnknown;
}

List<int> settingResponseProfileAgeLockListToJson(
    List<enums.SettingResponseProfileAgeLock>? settingResponseProfileAgeLock) {
  if (settingResponseProfileAgeLock == null) {
    return [];
  }

  return settingResponseProfileAgeLock
      .map((e) => enums.$SettingResponseProfileAgeLockMap[e]!)
      .toList();
}

List<enums.SettingResponseProfileAgeLock>
    settingResponseProfileAgeLockListFromJson(
  List? settingResponseProfileAgeLock, [
  List<enums.SettingResponseProfileAgeLock>? defaultValue,
]) {
  if (settingResponseProfileAgeLock == null) {
    return defaultValue ?? [];
  }

  return settingResponseProfileAgeLock
      .map((e) => settingResponseProfileAgeLockFromJson(e.toString()))
      .toList();
}

String? settingResponseProfileAudioLangToJson(
    enums.SettingResponseProfileAudioLang? settingResponseProfileAudioLang) {
  return enums
      .$SettingResponseProfileAudioLangMap[settingResponseProfileAudioLang];
}

enums.SettingResponseProfileAudioLang settingResponseProfileAudioLangFromJson(
  Object? settingResponseProfileAudioLang, [
  enums.SettingResponseProfileAudioLang? defaultValue,
]) {
  if (settingResponseProfileAudioLang is String) {
    return enums.$SettingResponseProfileAudioLangMap.entries
        .firstWhere(
            (element) =>
                element.value.toLowerCase() ==
                settingResponseProfileAudioLang.toLowerCase(),
            orElse: () => const MapEntry(
                enums.SettingResponseProfileAudioLang.swaggerGeneratedUnknown,
                ''))
        .key;
  }

  final parsedResult = defaultValue == null
      ? null
      : enums.$SettingResponseProfileAudioLangMap.entries
          .firstWhereOrNull((element) => element.value == defaultValue)
          ?.key;

  return parsedResult ??
      defaultValue ??
      enums.SettingResponseProfileAudioLang.swaggerGeneratedUnknown;
}

List<String> settingResponseProfileAudioLangListToJson(
    List<enums.SettingResponseProfileAudioLang>?
        settingResponseProfileAudioLang) {
  if (settingResponseProfileAudioLang == null) {
    return [];
  }

  return settingResponseProfileAudioLang
      .map((e) => enums.$SettingResponseProfileAudioLangMap[e]!)
      .toList();
}

List<enums.SettingResponseProfileAudioLang>
    settingResponseProfileAudioLangListFromJson(
  List? settingResponseProfileAudioLang, [
  List<enums.SettingResponseProfileAudioLang>? defaultValue,
]) {
  if (settingResponseProfileAudioLang == null) {
    return defaultValue ?? [];
  }

  return settingResponseProfileAudioLang
      .map((e) => settingResponseProfileAudioLangFromJson(e.toString()))
      .toList();
}

String? settingResponseCpeAudioDolbyDigitalModeToJson(
    enums.SettingResponseCpeAudioDolbyDigitalMode?
        settingResponseCpeAudioDolbyDigitalMode) {
  return enums.$SettingResponseCpeAudioDolbyDigitalModeMap[
      settingResponseCpeAudioDolbyDigitalMode];
}

enums.SettingResponseCpeAudioDolbyDigitalMode
    settingResponseCpeAudioDolbyDigitalModeFromJson(
  Object? settingResponseCpeAudioDolbyDigitalMode, [
  enums.SettingResponseCpeAudioDolbyDigitalMode? defaultValue,
]) {
  if (settingResponseCpeAudioDolbyDigitalMode is String) {
    return enums.$SettingResponseCpeAudioDolbyDigitalModeMap.entries
        .firstWhere(
            (element) =>
                element.value.toLowerCase() ==
                settingResponseCpeAudioDolbyDigitalMode.toLowerCase(),
            orElse: () => const MapEntry(
                enums.SettingResponseCpeAudioDolbyDigitalMode
                    .swaggerGeneratedUnknown,
                ''))
        .key;
  }

  final parsedResult = defaultValue == null
      ? null
      : enums.$SettingResponseCpeAudioDolbyDigitalModeMap.entries
          .firstWhereOrNull((element) => element.value == defaultValue)
          ?.key;

  return parsedResult ??
      defaultValue ??
      enums.SettingResponseCpeAudioDolbyDigitalMode.swaggerGeneratedUnknown;
}

List<String> settingResponseCpeAudioDolbyDigitalModeListToJson(
    List<enums.SettingResponseCpeAudioDolbyDigitalMode>?
        settingResponseCpeAudioDolbyDigitalMode) {
  if (settingResponseCpeAudioDolbyDigitalMode == null) {
    return [];
  }

  return settingResponseCpeAudioDolbyDigitalMode
      .map((e) => enums.$SettingResponseCpeAudioDolbyDigitalModeMap[e]!)
      .toList();
}

List<enums.SettingResponseCpeAudioDolbyDigitalMode>
    settingResponseCpeAudioDolbyDigitalModeListFromJson(
  List? settingResponseCpeAudioDolbyDigitalMode, [
  List<enums.SettingResponseCpeAudioDolbyDigitalMode>? defaultValue,
]) {
  if (settingResponseCpeAudioDolbyDigitalMode == null) {
    return defaultValue ?? [];
  }

  return settingResponseCpeAudioDolbyDigitalMode
      .map((e) => settingResponseCpeAudioDolbyDigitalModeFromJson(e.toString()))
      .toList();
}

String? settingResponseProfileSubLangToJson(
    enums.SettingResponseProfileSubLang? settingResponseProfileSubLang) {
  return enums.$SettingResponseProfileSubLangMap[settingResponseProfileSubLang];
}

enums.SettingResponseProfileSubLang settingResponseProfileSubLangFromJson(
  Object? settingResponseProfileSubLang, [
  enums.SettingResponseProfileSubLang? defaultValue,
]) {
  if (settingResponseProfileSubLang is String) {
    return enums.$SettingResponseProfileSubLangMap.entries
        .firstWhere(
            (element) =>
                element.value.toLowerCase() ==
                settingResponseProfileSubLang.toLowerCase(),
            orElse: () => const MapEntry(
                enums.SettingResponseProfileSubLang.swaggerGeneratedUnknown,
                ''))
        .key;
  }

  final parsedResult = defaultValue == null
      ? null
      : enums.$SettingResponseProfileSubLangMap.entries
          .firstWhereOrNull((element) => element.value == defaultValue)
          ?.key;

  return parsedResult ??
      defaultValue ??
      enums.SettingResponseProfileSubLang.swaggerGeneratedUnknown;
}

List<String> settingResponseProfileSubLangListToJson(
    List<enums.SettingResponseProfileSubLang>? settingResponseProfileSubLang) {
  if (settingResponseProfileSubLang == null) {
    return [];
  }

  return settingResponseProfileSubLang
      .map((e) => enums.$SettingResponseProfileSubLangMap[e]!)
      .toList();
}

List<enums.SettingResponseProfileSubLang>
    settingResponseProfileSubLangListFromJson(
  List? settingResponseProfileSubLang, [
  List<enums.SettingResponseProfileSubLang>? defaultValue,
]) {
  if (settingResponseProfileSubLang == null) {
    return defaultValue ?? [];
  }

  return settingResponseProfileSubLang
      .map((e) => settingResponseProfileSubLangFromJson(e.toString()))
      .toList();
}

String? settingResponseProfileOnScreenKeyboardModeToJson(
    enums.SettingResponseProfileOnScreenKeyboardMode?
        settingResponseProfileOnScreenKeyboardMode) {
  return enums.$SettingResponseProfileOnScreenKeyboardModeMap[
      settingResponseProfileOnScreenKeyboardMode];
}

enums.SettingResponseProfileOnScreenKeyboardMode
    settingResponseProfileOnScreenKeyboardModeFromJson(
  Object? settingResponseProfileOnScreenKeyboardMode, [
  enums.SettingResponseProfileOnScreenKeyboardMode? defaultValue,
]) {
  if (settingResponseProfileOnScreenKeyboardMode is String) {
    return enums.$SettingResponseProfileOnScreenKeyboardModeMap.entries
        .firstWhere(
            (element) =>
                element.value.toLowerCase() ==
                settingResponseProfileOnScreenKeyboardMode.toLowerCase(),
            orElse: () => const MapEntry(
                enums.SettingResponseProfileOnScreenKeyboardMode
                    .swaggerGeneratedUnknown,
                ''))
        .key;
  }

  final parsedResult = defaultValue == null
      ? null
      : enums.$SettingResponseProfileOnScreenKeyboardModeMap.entries
          .firstWhereOrNull((element) => element.value == defaultValue)
          ?.key;

  return parsedResult ??
      defaultValue ??
      enums.SettingResponseProfileOnScreenKeyboardMode.swaggerGeneratedUnknown;
}

List<String> settingResponseProfileOnScreenKeyboardModeListToJson(
    List<enums.SettingResponseProfileOnScreenKeyboardMode>?
        settingResponseProfileOnScreenKeyboardMode) {
  if (settingResponseProfileOnScreenKeyboardMode == null) {
    return [];
  }

  return settingResponseProfileOnScreenKeyboardMode
      .map((e) => enums.$SettingResponseProfileOnScreenKeyboardModeMap[e]!)
      .toList();
}

List<enums.SettingResponseProfileOnScreenKeyboardMode>
    settingResponseProfileOnScreenKeyboardModeListFromJson(
  List? settingResponseProfileOnScreenKeyboardMode, [
  List<enums.SettingResponseProfileOnScreenKeyboardMode>? defaultValue,
]) {
  if (settingResponseProfileOnScreenKeyboardMode == null) {
    return defaultValue ?? [];
  }

  return settingResponseProfileOnScreenKeyboardMode
      .map((e) =>
          settingResponseProfileOnScreenKeyboardModeFromJson(e.toString()))
      .toList();
}

String? settingResponseProfileTextToSpeechSpeedToJson(
    enums.SettingResponseProfileTextToSpeechSpeed?
        settingResponseProfileTextToSpeechSpeed) {
  return enums.$SettingResponseProfileTextToSpeechSpeedMap[
      settingResponseProfileTextToSpeechSpeed];
}

enums.SettingResponseProfileTextToSpeechSpeed
    settingResponseProfileTextToSpeechSpeedFromJson(
  Object? settingResponseProfileTextToSpeechSpeed, [
  enums.SettingResponseProfileTextToSpeechSpeed? defaultValue,
]) {
  if (settingResponseProfileTextToSpeechSpeed is String) {
    return enums.$SettingResponseProfileTextToSpeechSpeedMap.entries
        .firstWhere(
            (element) =>
                element.value.toLowerCase() ==
                settingResponseProfileTextToSpeechSpeed.toLowerCase(),
            orElse: () => const MapEntry(
                enums.SettingResponseProfileTextToSpeechSpeed
                    .swaggerGeneratedUnknown,
                ''))
        .key;
  }

  final parsedResult = defaultValue == null
      ? null
      : enums.$SettingResponseProfileTextToSpeechSpeedMap.entries
          .firstWhereOrNull((element) => element.value == defaultValue)
          ?.key;

  return parsedResult ??
      defaultValue ??
      enums.SettingResponseProfileTextToSpeechSpeed.swaggerGeneratedUnknown;
}

List<String> settingResponseProfileTextToSpeechSpeedListToJson(
    List<enums.SettingResponseProfileTextToSpeechSpeed>?
        settingResponseProfileTextToSpeechSpeed) {
  if (settingResponseProfileTextToSpeechSpeed == null) {
    return [];
  }

  return settingResponseProfileTextToSpeechSpeed
      .map((e) => enums.$SettingResponseProfileTextToSpeechSpeedMap[e]!)
      .toList();
}

List<enums.SettingResponseProfileTextToSpeechSpeed>
    settingResponseProfileTextToSpeechSpeedListFromJson(
  List? settingResponseProfileTextToSpeechSpeed, [
  List<enums.SettingResponseProfileTextToSpeechSpeed>? defaultValue,
]) {
  if (settingResponseProfileTextToSpeechSpeed == null) {
    return defaultValue ?? [];
  }

  return settingResponseProfileTextToSpeechSpeed
      .map((e) => settingResponseProfileTextToSpeechSpeedFromJson(e.toString()))
      .toList();
}

String? settingResponseProfileTextToSpeechVolumeToJson(
    enums.SettingResponseProfileTextToSpeechVolume?
        settingResponseProfileTextToSpeechVolume) {
  return enums.$SettingResponseProfileTextToSpeechVolumeMap[
      settingResponseProfileTextToSpeechVolume];
}

enums.SettingResponseProfileTextToSpeechVolume
    settingResponseProfileTextToSpeechVolumeFromJson(
  Object? settingResponseProfileTextToSpeechVolume, [
  enums.SettingResponseProfileTextToSpeechVolume? defaultValue,
]) {
  if (settingResponseProfileTextToSpeechVolume is String) {
    return enums.$SettingResponseProfileTextToSpeechVolumeMap.entries
        .firstWhere(
            (element) =>
                element.value.toLowerCase() ==
                settingResponseProfileTextToSpeechVolume.toLowerCase(),
            orElse: () => const MapEntry(
                enums.SettingResponseProfileTextToSpeechVolume
                    .swaggerGeneratedUnknown,
                ''))
        .key;
  }

  final parsedResult = defaultValue == null
      ? null
      : enums.$SettingResponseProfileTextToSpeechVolumeMap.entries
          .firstWhereOrNull((element) => element.value == defaultValue)
          ?.key;

  return parsedResult ??
      defaultValue ??
      enums.SettingResponseProfileTextToSpeechVolume.swaggerGeneratedUnknown;
}

List<String> settingResponseProfileTextToSpeechVolumeListToJson(
    List<enums.SettingResponseProfileTextToSpeechVolume>?
        settingResponseProfileTextToSpeechVolume) {
  if (settingResponseProfileTextToSpeechVolume == null) {
    return [];
  }

  return settingResponseProfileTextToSpeechVolume
      .map((e) => enums.$SettingResponseProfileTextToSpeechVolumeMap[e]!)
      .toList();
}

List<enums.SettingResponseProfileTextToSpeechVolume>
    settingResponseProfileTextToSpeechVolumeListFromJson(
  List? settingResponseProfileTextToSpeechVolume, [
  List<enums.SettingResponseProfileTextToSpeechVolume>? defaultValue,
]) {
  if (settingResponseProfileTextToSpeechVolume == null) {
    return defaultValue ?? [];
  }

  return settingResponseProfileTextToSpeechVolume
      .map(
          (e) => settingResponseProfileTextToSpeechVolumeFromJson(e.toString()))
      .toList();
}

int? settingResponseCpeRecordPaddingBeforeToJson(
    enums.SettingResponseCpeRecordPaddingBefore?
        settingResponseCpeRecordPaddingBefore) {
  return enums.$SettingResponseCpeRecordPaddingBeforeMap[
      settingResponseCpeRecordPaddingBefore];
}

enums.SettingResponseCpeRecordPaddingBefore
    settingResponseCpeRecordPaddingBeforeFromJson(
  Object? settingResponseCpeRecordPaddingBefore, [
  enums.SettingResponseCpeRecordPaddingBefore? defaultValue,
]) {
  if (settingResponseCpeRecordPaddingBefore is int) {
    return enums.$SettingResponseCpeRecordPaddingBeforeMap.entries
        .firstWhere(
            (element) => element.value == settingResponseCpeRecordPaddingBefore,
            orElse: () => const MapEntry(
                enums.SettingResponseCpeRecordPaddingBefore
                    .swaggerGeneratedUnknown,
                0))
        .key;
  }

  final parsedResult = defaultValue == null
      ? null
      : enums.$SettingResponseCpeRecordPaddingBeforeMap.entries
          .firstWhereOrNull((element) => element.value == defaultValue)
          ?.key;

  return parsedResult ??
      defaultValue ??
      enums.SettingResponseCpeRecordPaddingBefore.swaggerGeneratedUnknown;
}

List<int> settingResponseCpeRecordPaddingBeforeListToJson(
    List<enums.SettingResponseCpeRecordPaddingBefore>?
        settingResponseCpeRecordPaddingBefore) {
  if (settingResponseCpeRecordPaddingBefore == null) {
    return [];
  }

  return settingResponseCpeRecordPaddingBefore
      .map((e) => enums.$SettingResponseCpeRecordPaddingBeforeMap[e]!)
      .toList();
}

List<enums.SettingResponseCpeRecordPaddingBefore>
    settingResponseCpeRecordPaddingBeforeListFromJson(
  List? settingResponseCpeRecordPaddingBefore, [
  List<enums.SettingResponseCpeRecordPaddingBefore>? defaultValue,
]) {
  if (settingResponseCpeRecordPaddingBefore == null) {
    return defaultValue ?? [];
  }

  return settingResponseCpeRecordPaddingBefore
      .map((e) => settingResponseCpeRecordPaddingBeforeFromJson(e.toString()))
      .toList();
}

int? settingResponseCpeRecordPaddingAfterToJson(
    enums.SettingResponseCpeRecordPaddingAfter?
        settingResponseCpeRecordPaddingAfter) {
  return enums.$SettingResponseCpeRecordPaddingAfterMap[
      settingResponseCpeRecordPaddingAfter];
}

enums.SettingResponseCpeRecordPaddingAfter
    settingResponseCpeRecordPaddingAfterFromJson(
  Object? settingResponseCpeRecordPaddingAfter, [
  enums.SettingResponseCpeRecordPaddingAfter? defaultValue,
]) {
  if (settingResponseCpeRecordPaddingAfter is int) {
    return enums.$SettingResponseCpeRecordPaddingAfterMap.entries
        .firstWhere(
            (element) => element.value == settingResponseCpeRecordPaddingAfter,
            orElse: () => const MapEntry(
                enums.SettingResponseCpeRecordPaddingAfter
                    .swaggerGeneratedUnknown,
                0))
        .key;
  }

  final parsedResult = defaultValue == null
      ? null
      : enums.$SettingResponseCpeRecordPaddingAfterMap.entries
          .firstWhereOrNull((element) => element.value == defaultValue)
          ?.key;

  return parsedResult ??
      defaultValue ??
      enums.SettingResponseCpeRecordPaddingAfter.swaggerGeneratedUnknown;
}

List<int> settingResponseCpeRecordPaddingAfterListToJson(
    List<enums.SettingResponseCpeRecordPaddingAfter>?
        settingResponseCpeRecordPaddingAfter) {
  if (settingResponseCpeRecordPaddingAfter == null) {
    return [];
  }

  return settingResponseCpeRecordPaddingAfter
      .map((e) => enums.$SettingResponseCpeRecordPaddingAfterMap[e]!)
      .toList();
}

List<enums.SettingResponseCpeRecordPaddingAfter>
    settingResponseCpeRecordPaddingAfterListFromJson(
  List? settingResponseCpeRecordPaddingAfter, [
  List<enums.SettingResponseCpeRecordPaddingAfter>? defaultValue,
]) {
  if (settingResponseCpeRecordPaddingAfter == null) {
    return defaultValue ?? [];
  }

  return settingResponseCpeRecordPaddingAfter
      .map((e) => settingResponseCpeRecordPaddingAfterFromJson(e.toString()))
      .toList();
}

String? settingResponseCpeFactoryResetStateToJson(
    enums.SettingResponseCpeFactoryResetState?
        settingResponseCpeFactoryResetState) {
  return enums.$SettingResponseCpeFactoryResetStateMap[
      settingResponseCpeFactoryResetState];
}

enums.SettingResponseCpeFactoryResetState
    settingResponseCpeFactoryResetStateFromJson(
  Object? settingResponseCpeFactoryResetState, [
  enums.SettingResponseCpeFactoryResetState? defaultValue,
]) {
  if (settingResponseCpeFactoryResetState is String) {
    return enums.$SettingResponseCpeFactoryResetStateMap.entries
        .firstWhere(
            (element) =>
                element.value.toLowerCase() ==
                settingResponseCpeFactoryResetState.toLowerCase(),
            orElse: () => const MapEntry(
                enums.SettingResponseCpeFactoryResetState
                    .swaggerGeneratedUnknown,
                ''))
        .key;
  }

  final parsedResult = defaultValue == null
      ? null
      : enums.$SettingResponseCpeFactoryResetStateMap.entries
          .firstWhereOrNull((element) => element.value == defaultValue)
          ?.key;

  return parsedResult ??
      defaultValue ??
      enums.SettingResponseCpeFactoryResetState.swaggerGeneratedUnknown;
}

List<String> settingResponseCpeFactoryResetStateListToJson(
    List<enums.SettingResponseCpeFactoryResetState>?
        settingResponseCpeFactoryResetState) {
  if (settingResponseCpeFactoryResetState == null) {
    return [];
  }

  return settingResponseCpeFactoryResetState
      .map((e) => enums.$SettingResponseCpeFactoryResetStateMap[e]!)
      .toList();
}

List<enums.SettingResponseCpeFactoryResetState>
    settingResponseCpeFactoryResetStateListFromJson(
  List? settingResponseCpeFactoryResetState, [
  List<enums.SettingResponseCpeFactoryResetState>? defaultValue,
]) {
  if (settingResponseCpeFactoryResetState == null) {
    return defaultValue ?? [];
  }

  return settingResponseCpeFactoryResetState
      .map((e) => settingResponseCpeFactoryResetStateFromJson(e.toString()))
      .toList();
}

String? settingResponseCpeHdmiResolutionToJson(
    enums.SettingResponseCpeHdmiResolution? settingResponseCpeHdmiResolution) {
  return enums
      .$SettingResponseCpeHdmiResolutionMap[settingResponseCpeHdmiResolution];
}

enums.SettingResponseCpeHdmiResolution settingResponseCpeHdmiResolutionFromJson(
  Object? settingResponseCpeHdmiResolution, [
  enums.SettingResponseCpeHdmiResolution? defaultValue,
]) {
  if (settingResponseCpeHdmiResolution is String) {
    return enums.$SettingResponseCpeHdmiResolutionMap.entries
        .firstWhere(
            (element) =>
                element.value.toLowerCase() ==
                settingResponseCpeHdmiResolution.toLowerCase(),
            orElse: () => const MapEntry(
                enums.SettingResponseCpeHdmiResolution.swaggerGeneratedUnknown,
                ''))
        .key;
  }

  final parsedResult = defaultValue == null
      ? null
      : enums.$SettingResponseCpeHdmiResolutionMap.entries
          .firstWhereOrNull((element) => element.value == defaultValue)
          ?.key;

  return parsedResult ??
      defaultValue ??
      enums.SettingResponseCpeHdmiResolution.swaggerGeneratedUnknown;
}

List<String> settingResponseCpeHdmiResolutionListToJson(
    List<enums.SettingResponseCpeHdmiResolution>?
        settingResponseCpeHdmiResolution) {
  if (settingResponseCpeHdmiResolution == null) {
    return [];
  }

  return settingResponseCpeHdmiResolution
      .map((e) => enums.$SettingResponseCpeHdmiResolutionMap[e]!)
      .toList();
}

List<enums.SettingResponseCpeHdmiResolution>
    settingResponseCpeHdmiResolutionListFromJson(
  List? settingResponseCpeHdmiResolution, [
  List<enums.SettingResponseCpeHdmiResolution>? defaultValue,
]) {
  if (settingResponseCpeHdmiResolution == null) {
    return defaultValue ?? [];
  }

  return settingResponseCpeHdmiResolution
      .map((e) => settingResponseCpeHdmiResolutionFromJson(e.toString()))
      .toList();
}

String? settingResponseCpePrimaryVideoOutputToJson(
    enums.SettingResponseCpePrimaryVideoOutput?
        settingResponseCpePrimaryVideoOutput) {
  return enums.$SettingResponseCpePrimaryVideoOutputMap[
      settingResponseCpePrimaryVideoOutput];
}

enums.SettingResponseCpePrimaryVideoOutput
    settingResponseCpePrimaryVideoOutputFromJson(
  Object? settingResponseCpePrimaryVideoOutput, [
  enums.SettingResponseCpePrimaryVideoOutput? defaultValue,
]) {
  if (settingResponseCpePrimaryVideoOutput is String) {
    return enums.$SettingResponseCpePrimaryVideoOutputMap.entries
        .firstWhere(
            (element) =>
                element.value.toLowerCase() ==
                settingResponseCpePrimaryVideoOutput.toLowerCase(),
            orElse: () => const MapEntry(
                enums.SettingResponseCpePrimaryVideoOutput
                    .swaggerGeneratedUnknown,
                ''))
        .key;
  }

  final parsedResult = defaultValue == null
      ? null
      : enums.$SettingResponseCpePrimaryVideoOutputMap.entries
          .firstWhereOrNull((element) => element.value == defaultValue)
          ?.key;

  return parsedResult ??
      defaultValue ??
      enums.SettingResponseCpePrimaryVideoOutput.swaggerGeneratedUnknown;
}

List<String> settingResponseCpePrimaryVideoOutputListToJson(
    List<enums.SettingResponseCpePrimaryVideoOutput>?
        settingResponseCpePrimaryVideoOutput) {
  if (settingResponseCpePrimaryVideoOutput == null) {
    return [];
  }

  return settingResponseCpePrimaryVideoOutput
      .map((e) => enums.$SettingResponseCpePrimaryVideoOutputMap[e]!)
      .toList();
}

List<enums.SettingResponseCpePrimaryVideoOutput>
    settingResponseCpePrimaryVideoOutputListFromJson(
  List? settingResponseCpePrimaryVideoOutput, [
  List<enums.SettingResponseCpePrimaryVideoOutput>? defaultValue,
]) {
  if (settingResponseCpePrimaryVideoOutput == null) {
    return defaultValue ?? [];
  }

  return settingResponseCpePrimaryVideoOutput
      .map((e) => settingResponseCpePrimaryVideoOutputFromJson(e.toString()))
      .toList();
}

String? settingResponseCpeAspectRatioToJson(
    enums.SettingResponseCpeAspectRatio? settingResponseCpeAspectRatio) {
  return enums.$SettingResponseCpeAspectRatioMap[settingResponseCpeAspectRatio];
}

enums.SettingResponseCpeAspectRatio settingResponseCpeAspectRatioFromJson(
  Object? settingResponseCpeAspectRatio, [
  enums.SettingResponseCpeAspectRatio? defaultValue,
]) {
  if (settingResponseCpeAspectRatio is String) {
    return enums.$SettingResponseCpeAspectRatioMap.entries
        .firstWhere(
            (element) =>
                element.value.toLowerCase() ==
                settingResponseCpeAspectRatio.toLowerCase(),
            orElse: () => const MapEntry(
                enums.SettingResponseCpeAspectRatio.swaggerGeneratedUnknown,
                ''))
        .key;
  }

  final parsedResult = defaultValue == null
      ? null
      : enums.$SettingResponseCpeAspectRatioMap.entries
          .firstWhereOrNull((element) => element.value == defaultValue)
          ?.key;

  return parsedResult ??
      defaultValue ??
      enums.SettingResponseCpeAspectRatio.swaggerGeneratedUnknown;
}

List<String> settingResponseCpeAspectRatioListToJson(
    List<enums.SettingResponseCpeAspectRatio>? settingResponseCpeAspectRatio) {
  if (settingResponseCpeAspectRatio == null) {
    return [];
  }

  return settingResponseCpeAspectRatio
      .map((e) => enums.$SettingResponseCpeAspectRatioMap[e]!)
      .toList();
}

List<enums.SettingResponseCpeAspectRatio>
    settingResponseCpeAspectRatioListFromJson(
  List? settingResponseCpeAspectRatio, [
  List<enums.SettingResponseCpeAspectRatio>? defaultValue,
]) {
  if (settingResponseCpeAspectRatio == null) {
    return defaultValue ?? [];
  }

  return settingResponseCpeAspectRatio
      .map((e) => settingResponseCpeAspectRatioFromJson(e.toString()))
      .toList();
}

String? settingResponseCpeHdmiColorOutputToJson(
    enums.SettingResponseCpeHdmiColorOutput?
        settingResponseCpeHdmiColorOutput) {
  return enums
      .$SettingResponseCpeHdmiColorOutputMap[settingResponseCpeHdmiColorOutput];
}

enums.SettingResponseCpeHdmiColorOutput
    settingResponseCpeHdmiColorOutputFromJson(
  Object? settingResponseCpeHdmiColorOutput, [
  enums.SettingResponseCpeHdmiColorOutput? defaultValue,
]) {
  if (settingResponseCpeHdmiColorOutput is String) {
    return enums.$SettingResponseCpeHdmiColorOutputMap.entries
        .firstWhere(
            (element) =>
                element.value.toLowerCase() ==
                settingResponseCpeHdmiColorOutput.toLowerCase(),
            orElse: () => const MapEntry(
                enums.SettingResponseCpeHdmiColorOutput.swaggerGeneratedUnknown,
                ''))
        .key;
  }

  final parsedResult = defaultValue == null
      ? null
      : enums.$SettingResponseCpeHdmiColorOutputMap.entries
          .firstWhereOrNull((element) => element.value == defaultValue)
          ?.key;

  return parsedResult ??
      defaultValue ??
      enums.SettingResponseCpeHdmiColorOutput.swaggerGeneratedUnknown;
}

List<String> settingResponseCpeHdmiColorOutputListToJson(
    List<enums.SettingResponseCpeHdmiColorOutput>?
        settingResponseCpeHdmiColorOutput) {
  if (settingResponseCpeHdmiColorOutput == null) {
    return [];
  }

  return settingResponseCpeHdmiColorOutput
      .map((e) => enums.$SettingResponseCpeHdmiColorOutputMap[e]!)
      .toList();
}

List<enums.SettingResponseCpeHdmiColorOutput>
    settingResponseCpeHdmiColorOutputListFromJson(
  List? settingResponseCpeHdmiColorOutput, [
  List<enums.SettingResponseCpeHdmiColorOutput>? defaultValue,
]) {
  if (settingResponseCpeHdmiColorOutput == null) {
    return defaultValue ?? [];
  }

  return settingResponseCpeHdmiColorOutput
      .map((e) => settingResponseCpeHdmiColorOutputFromJson(e.toString()))
      .toList();
}

String? settingResponseCpe4by3HandlingToJson(
    enums.SettingResponseCpe4by3Handling? settingResponseCpe4by3Handling) {
  return enums
      .$SettingResponseCpe4by3HandlingMap[settingResponseCpe4by3Handling];
}

enums.SettingResponseCpe4by3Handling settingResponseCpe4by3HandlingFromJson(
  Object? settingResponseCpe4by3Handling, [
  enums.SettingResponseCpe4by3Handling? defaultValue,
]) {
  if (settingResponseCpe4by3Handling is String) {
    return enums.$SettingResponseCpe4by3HandlingMap.entries
        .firstWhere(
            (element) =>
                element.value.toLowerCase() ==
                settingResponseCpe4by3Handling.toLowerCase(),
            orElse: () => const MapEntry(
                enums.SettingResponseCpe4by3Handling.swaggerGeneratedUnknown,
                ''))
        .key;
  }

  final parsedResult = defaultValue == null
      ? null
      : enums.$SettingResponseCpe4by3HandlingMap.entries
          .firstWhereOrNull((element) => element.value == defaultValue)
          ?.key;

  return parsedResult ??
      defaultValue ??
      enums.SettingResponseCpe4by3Handling.swaggerGeneratedUnknown;
}

List<String> settingResponseCpe4by3HandlingListToJson(
    List<enums.SettingResponseCpe4by3Handling>?
        settingResponseCpe4by3Handling) {
  if (settingResponseCpe4by3Handling == null) {
    return [];
  }

  return settingResponseCpe4by3Handling
      .map((e) => enums.$SettingResponseCpe4by3HandlingMap[e]!)
      .toList();
}

List<enums.SettingResponseCpe4by3Handling>
    settingResponseCpe4by3HandlingListFromJson(
  List? settingResponseCpe4by3Handling, [
  List<enums.SettingResponseCpe4by3Handling>? defaultValue,
]) {
  if (settingResponseCpe4by3Handling == null) {
    return defaultValue ?? [];
  }

  return settingResponseCpe4by3Handling
      .map((e) => settingResponseCpe4by3HandlingFromJson(e.toString()))
      .toList();
}

String? settingResponseCpe16by9HandlingToJson(
    enums.SettingResponseCpe16by9Handling? settingResponseCpe16by9Handling) {
  return enums
      .$SettingResponseCpe16by9HandlingMap[settingResponseCpe16by9Handling];
}

enums.SettingResponseCpe16by9Handling settingResponseCpe16by9HandlingFromJson(
  Object? settingResponseCpe16by9Handling, [
  enums.SettingResponseCpe16by9Handling? defaultValue,
]) {
  if (settingResponseCpe16by9Handling is String) {
    return enums.$SettingResponseCpe16by9HandlingMap.entries
        .firstWhere(
            (element) =>
                element.value.toLowerCase() ==
                settingResponseCpe16by9Handling.toLowerCase(),
            orElse: () => const MapEntry(
                enums.SettingResponseCpe16by9Handling.swaggerGeneratedUnknown,
                ''))
        .key;
  }

  final parsedResult = defaultValue == null
      ? null
      : enums.$SettingResponseCpe16by9HandlingMap.entries
          .firstWhereOrNull((element) => element.value == defaultValue)
          ?.key;

  return parsedResult ??
      defaultValue ??
      enums.SettingResponseCpe16by9Handling.swaggerGeneratedUnknown;
}

List<String> settingResponseCpe16by9HandlingListToJson(
    List<enums.SettingResponseCpe16by9Handling>?
        settingResponseCpe16by9Handling) {
  if (settingResponseCpe16by9Handling == null) {
    return [];
  }

  return settingResponseCpe16by9Handling
      .map((e) => enums.$SettingResponseCpe16by9HandlingMap[e]!)
      .toList();
}

List<enums.SettingResponseCpe16by9Handling>
    settingResponseCpe16by9HandlingListFromJson(
  List? settingResponseCpe16by9Handling, [
  List<enums.SettingResponseCpe16by9Handling>? defaultValue,
]) {
  if (settingResponseCpe16by9Handling == null) {
    return defaultValue ?? [];
  }

  return settingResponseCpe16by9Handling
      .map((e) => settingResponseCpe16by9HandlingFromJson(e.toString()))
      .toList();
}

int? settingResponseCpeAutoStandbyToJson(
    enums.SettingResponseCpeAutoStandby? settingResponseCpeAutoStandby) {
  return enums.$SettingResponseCpeAutoStandbyMap[settingResponseCpeAutoStandby];
}

enums.SettingResponseCpeAutoStandby settingResponseCpeAutoStandbyFromJson(
  Object? settingResponseCpeAutoStandby, [
  enums.SettingResponseCpeAutoStandby? defaultValue,
]) {
  if (settingResponseCpeAutoStandby is int) {
    return enums.$SettingResponseCpeAutoStandbyMap.entries
        .firstWhere((element) => element.value == settingResponseCpeAutoStandby,
            orElse: () => const MapEntry(
                enums.SettingResponseCpeAutoStandby.swaggerGeneratedUnknown, 0))
        .key;
  }

  final parsedResult = defaultValue == null
      ? null
      : enums.$SettingResponseCpeAutoStandbyMap.entries
          .firstWhereOrNull((element) => element.value == defaultValue)
          ?.key;

  return parsedResult ??
      defaultValue ??
      enums.SettingResponseCpeAutoStandby.swaggerGeneratedUnknown;
}

List<int> settingResponseCpeAutoStandbyListToJson(
    List<enums.SettingResponseCpeAutoStandby>? settingResponseCpeAutoStandby) {
  if (settingResponseCpeAutoStandby == null) {
    return [];
  }

  return settingResponseCpeAutoStandby
      .map((e) => enums.$SettingResponseCpeAutoStandbyMap[e]!)
      .toList();
}

List<enums.SettingResponseCpeAutoStandby>
    settingResponseCpeAutoStandbyListFromJson(
  List? settingResponseCpeAutoStandby, [
  List<enums.SettingResponseCpeAutoStandby>? defaultValue,
]) {
  if (settingResponseCpeAutoStandby == null) {
    return defaultValue ?? [];
  }

  return settingResponseCpeAutoStandby
      .map((e) => settingResponseCpeAutoStandbyFromJson(e.toString()))
      .toList();
}

String? settingResponseCpeStandByModeToJson(
    enums.SettingResponseCpeStandByMode? settingResponseCpeStandByMode) {
  return enums.$SettingResponseCpeStandByModeMap[settingResponseCpeStandByMode];
}

enums.SettingResponseCpeStandByMode settingResponseCpeStandByModeFromJson(
  Object? settingResponseCpeStandByMode, [
  enums.SettingResponseCpeStandByMode? defaultValue,
]) {
  if (settingResponseCpeStandByMode is String) {
    return enums.$SettingResponseCpeStandByModeMap.entries
        .firstWhere(
            (element) =>
                element.value.toLowerCase() ==
                settingResponseCpeStandByMode.toLowerCase(),
            orElse: () => const MapEntry(
                enums.SettingResponseCpeStandByMode.swaggerGeneratedUnknown,
                ''))
        .key;
  }

  final parsedResult = defaultValue == null
      ? null
      : enums.$SettingResponseCpeStandByModeMap.entries
          .firstWhereOrNull((element) => element.value == defaultValue)
          ?.key;

  return parsedResult ??
      defaultValue ??
      enums.SettingResponseCpeStandByMode.swaggerGeneratedUnknown;
}

List<String> settingResponseCpeStandByModeListToJson(
    List<enums.SettingResponseCpeStandByMode>? settingResponseCpeStandByMode) {
  if (settingResponseCpeStandByMode == null) {
    return [];
  }

  return settingResponseCpeStandByMode
      .map((e) => enums.$SettingResponseCpeStandByModeMap[e]!)
      .toList();
}

List<enums.SettingResponseCpeStandByMode>
    settingResponseCpeStandByModeListFromJson(
  List? settingResponseCpeStandByMode, [
  List<enums.SettingResponseCpeStandByMode>? defaultValue,
]) {
  if (settingResponseCpeStandByMode == null) {
    return defaultValue ?? [];
  }

  return settingResponseCpeStandByMode
      .map((e) => settingResponseCpeStandByModeFromJson(e.toString()))
      .toList();
}

String? settingResponseCpePowerCheckToJson(
    enums.SettingResponseCpePowerCheck? settingResponseCpePowerCheck) {
  return enums.$SettingResponseCpePowerCheckMap[settingResponseCpePowerCheck];
}

enums.SettingResponseCpePowerCheck settingResponseCpePowerCheckFromJson(
  Object? settingResponseCpePowerCheck, [
  enums.SettingResponseCpePowerCheck? defaultValue,
]) {
  if (settingResponseCpePowerCheck is String) {
    return enums.$SettingResponseCpePowerCheckMap.entries
        .firstWhere(
            (element) =>
                element.value.toLowerCase() ==
                settingResponseCpePowerCheck.toLowerCase(),
            orElse: () => const MapEntry(
                enums.SettingResponseCpePowerCheck.swaggerGeneratedUnknown, ''))
        .key;
  }

  final parsedResult = defaultValue == null
      ? null
      : enums.$SettingResponseCpePowerCheckMap.entries
          .firstWhereOrNull((element) => element.value == defaultValue)
          ?.key;

  return parsedResult ??
      defaultValue ??
      enums.SettingResponseCpePowerCheck.swaggerGeneratedUnknown;
}

List<String> settingResponseCpePowerCheckListToJson(
    List<enums.SettingResponseCpePowerCheck>? settingResponseCpePowerCheck) {
  if (settingResponseCpePowerCheck == null) {
    return [];
  }

  return settingResponseCpePowerCheck
      .map((e) => enums.$SettingResponseCpePowerCheckMap[e]!)
      .toList();
}

List<enums.SettingResponseCpePowerCheck>
    settingResponseCpePowerCheckListFromJson(
  List? settingResponseCpePowerCheck, [
  List<enums.SettingResponseCpePowerCheck>? defaultValue,
]) {
  if (settingResponseCpePowerCheck == null) {
    return defaultValue ?? [];
  }

  return settingResponseCpePowerCheck
      .map((e) => settingResponseCpePowerCheckFromJson(e.toString()))
      .toList();
}

String? settingResponseCpePowerSourceToJson(
    enums.SettingResponseCpePowerSource? settingResponseCpePowerSource) {
  return enums.$SettingResponseCpePowerSourceMap[settingResponseCpePowerSource];
}

enums.SettingResponseCpePowerSource settingResponseCpePowerSourceFromJson(
  Object? settingResponseCpePowerSource, [
  enums.SettingResponseCpePowerSource? defaultValue,
]) {
  if (settingResponseCpePowerSource is String) {
    return enums.$SettingResponseCpePowerSourceMap.entries
        .firstWhere(
            (element) =>
                element.value.toLowerCase() ==
                settingResponseCpePowerSource.toLowerCase(),
            orElse: () => const MapEntry(
                enums.SettingResponseCpePowerSource.swaggerGeneratedUnknown,
                ''))
        .key;
  }

  final parsedResult = defaultValue == null
      ? null
      : enums.$SettingResponseCpePowerSourceMap.entries
          .firstWhereOrNull((element) => element.value == defaultValue)
          ?.key;

  return parsedResult ??
      defaultValue ??
      enums.SettingResponseCpePowerSource.swaggerGeneratedUnknown;
}

List<String> settingResponseCpePowerSourceListToJson(
    List<enums.SettingResponseCpePowerSource>? settingResponseCpePowerSource) {
  if (settingResponseCpePowerSource == null) {
    return [];
  }

  return settingResponseCpePowerSource
      .map((e) => enums.$SettingResponseCpePowerSourceMap[e]!)
      .toList();
}

List<enums.SettingResponseCpePowerSource>
    settingResponseCpePowerSourceListFromJson(
  List? settingResponseCpePowerSource, [
  List<enums.SettingResponseCpePowerSource>? defaultValue,
]) {
  if (settingResponseCpePowerSource == null) {
    return defaultValue ?? [];
  }

  return settingResponseCpePowerSource
      .map((e) => settingResponseCpePowerSourceFromJson(e.toString()))
      .toList();
}

String? settingResponseCpeCcAnalogServiceToJson(
    enums.SettingResponseCpeCcAnalogService?
        settingResponseCpeCcAnalogService) {
  return enums
      .$SettingResponseCpeCcAnalogServiceMap[settingResponseCpeCcAnalogService];
}

enums.SettingResponseCpeCcAnalogService
    settingResponseCpeCcAnalogServiceFromJson(
  Object? settingResponseCpeCcAnalogService, [
  enums.SettingResponseCpeCcAnalogService? defaultValue,
]) {
  if (settingResponseCpeCcAnalogService is String) {
    return enums.$SettingResponseCpeCcAnalogServiceMap.entries
        .firstWhere(
            (element) =>
                element.value.toLowerCase() ==
                settingResponseCpeCcAnalogService.toLowerCase(),
            orElse: () => const MapEntry(
                enums.SettingResponseCpeCcAnalogService.swaggerGeneratedUnknown,
                ''))
        .key;
  }

  final parsedResult = defaultValue == null
      ? null
      : enums.$SettingResponseCpeCcAnalogServiceMap.entries
          .firstWhereOrNull((element) => element.value == defaultValue)
          ?.key;

  return parsedResult ??
      defaultValue ??
      enums.SettingResponseCpeCcAnalogService.swaggerGeneratedUnknown;
}

List<String> settingResponseCpeCcAnalogServiceListToJson(
    List<enums.SettingResponseCpeCcAnalogService>?
        settingResponseCpeCcAnalogService) {
  if (settingResponseCpeCcAnalogService == null) {
    return [];
  }

  return settingResponseCpeCcAnalogService
      .map((e) => enums.$SettingResponseCpeCcAnalogServiceMap[e]!)
      .toList();
}

List<enums.SettingResponseCpeCcAnalogService>
    settingResponseCpeCcAnalogServiceListFromJson(
  List? settingResponseCpeCcAnalogService, [
  List<enums.SettingResponseCpeCcAnalogService>? defaultValue,
]) {
  if (settingResponseCpeCcAnalogService == null) {
    return defaultValue ?? [];
  }

  return settingResponseCpeCcAnalogService
      .map((e) => settingResponseCpeCcAnalogServiceFromJson(e.toString()))
      .toList();
}

String? settingResponseCpeCcDigitalServiceToJson(
    enums.SettingResponseCpeCcDigitalService?
        settingResponseCpeCcDigitalService) {
  return enums.$SettingResponseCpeCcDigitalServiceMap[
      settingResponseCpeCcDigitalService];
}

enums.SettingResponseCpeCcDigitalService
    settingResponseCpeCcDigitalServiceFromJson(
  Object? settingResponseCpeCcDigitalService, [
  enums.SettingResponseCpeCcDigitalService? defaultValue,
]) {
  if (settingResponseCpeCcDigitalService is String) {
    return enums.$SettingResponseCpeCcDigitalServiceMap.entries
        .firstWhere(
            (element) =>
                element.value.toLowerCase() ==
                settingResponseCpeCcDigitalService.toLowerCase(),
            orElse: () => const MapEntry(
                enums
                    .SettingResponseCpeCcDigitalService.swaggerGeneratedUnknown,
                ''))
        .key;
  }

  final parsedResult = defaultValue == null
      ? null
      : enums.$SettingResponseCpeCcDigitalServiceMap.entries
          .firstWhereOrNull((element) => element.value == defaultValue)
          ?.key;

  return parsedResult ??
      defaultValue ??
      enums.SettingResponseCpeCcDigitalService.swaggerGeneratedUnknown;
}

List<String> settingResponseCpeCcDigitalServiceListToJson(
    List<enums.SettingResponseCpeCcDigitalService>?
        settingResponseCpeCcDigitalService) {
  if (settingResponseCpeCcDigitalService == null) {
    return [];
  }

  return settingResponseCpeCcDigitalService
      .map((e) => enums.$SettingResponseCpeCcDigitalServiceMap[e]!)
      .toList();
}

List<enums.SettingResponseCpeCcDigitalService>
    settingResponseCpeCcDigitalServiceListFromJson(
  List? settingResponseCpeCcDigitalService, [
  List<enums.SettingResponseCpeCcDigitalService>? defaultValue,
]) {
  if (settingResponseCpeCcDigitalService == null) {
    return defaultValue ?? [];
  }

  return settingResponseCpeCcDigitalService
      .map((e) => settingResponseCpeCcDigitalServiceFromJson(e.toString()))
      .toList();
}

int? settingResponseCustomerRecordingRetentionPeriodToJson(
    enums.SettingResponseCustomerRecordingRetentionPeriod?
        settingResponseCustomerRecordingRetentionPeriod) {
  return enums.$SettingResponseCustomerRecordingRetentionPeriodMap[
      settingResponseCustomerRecordingRetentionPeriod];
}

enums.SettingResponseCustomerRecordingRetentionPeriod
    settingResponseCustomerRecordingRetentionPeriodFromJson(
  Object? settingResponseCustomerRecordingRetentionPeriod, [
  enums.SettingResponseCustomerRecordingRetentionPeriod? defaultValue,
]) {
  if (settingResponseCustomerRecordingRetentionPeriod is int) {
    return enums.$SettingResponseCustomerRecordingRetentionPeriodMap.entries
        .firstWhere(
            (element) =>
                element.value ==
                settingResponseCustomerRecordingRetentionPeriod,
            orElse: () => const MapEntry(
                enums.SettingResponseCustomerRecordingRetentionPeriod
                    .swaggerGeneratedUnknown,
                0))
        .key;
  }

  final parsedResult = defaultValue == null
      ? null
      : enums.$SettingResponseCustomerRecordingRetentionPeriodMap.entries
          .firstWhereOrNull((element) => element.value == defaultValue)
          ?.key;

  return parsedResult ??
      defaultValue ??
      enums.SettingResponseCustomerRecordingRetentionPeriod
          .swaggerGeneratedUnknown;
}

List<int> settingResponseCustomerRecordingRetentionPeriodListToJson(
    List<enums.SettingResponseCustomerRecordingRetentionPeriod>?
        settingResponseCustomerRecordingRetentionPeriod) {
  if (settingResponseCustomerRecordingRetentionPeriod == null) {
    return [];
  }

  return settingResponseCustomerRecordingRetentionPeriod
      .map((e) => enums.$SettingResponseCustomerRecordingRetentionPeriodMap[e]!)
      .toList();
}

List<enums.SettingResponseCustomerRecordingRetentionPeriod>
    settingResponseCustomerRecordingRetentionPeriodListFromJson(
  List? settingResponseCustomerRecordingRetentionPeriod, [
  List<enums.SettingResponseCustomerRecordingRetentionPeriod>? defaultValue,
]) {
  if (settingResponseCustomerRecordingRetentionPeriod == null) {
    return defaultValue ?? [];
  }

  return settingResponseCustomerRecordingRetentionPeriod
      .map((e) =>
          settingResponseCustomerRecordingRetentionPeriodFromJson(e.toString()))
      .toList();
}

typedef $JsonFactory<T> = T Function(Map<String, dynamic> json);

class $CustomJsonDecoder {
  $CustomJsonDecoder(this.factories);

  final Map<Type, $JsonFactory> factories;

  dynamic decode<T>(dynamic entity) {
    if (entity is Iterable) {
      return _decodeList<T>(entity);
    }

    if (entity is T) {
      return entity;
    }

    if (isTypeOf<T, Map>()) {
      return entity;
    }

    if (isTypeOf<T, Iterable>()) {
      return entity;
    }

    if (entity is Map<String, dynamic>) {
      return _decodeMap<T>(entity);
    }

    return entity;
  }

  T _decodeMap<T>(Map<String, dynamic> values) {
    final jsonFactory = factories[T];
    if (jsonFactory == null || jsonFactory is! $JsonFactory<T>) {
      return throw "Could not find factory for type $T. Is '$T: $T.fromJsonFactory' included in the CustomJsonDecoder instance creation in bootstrapper.dart?";
    }

    return jsonFactory(values);
  }

  List<T> _decodeList<T>(Iterable values) =>
      values.where((v) => v != null).map<T>((v) => decode<T>(v) as T).toList();
}

class $JsonSerializableConverter extends chopper.JsonConverter {
  @override
  chopper.Response<ResultType> convertResponse<ResultType, Item>(
      chopper.Response response) {
    if (response.bodyString.isEmpty) {
      // In rare cases, when let's say 204 (no content) is returned -
      // we cannot decode the missing json with the result type specified
      return chopper.Response(response.base, null, error: response.error);
    }

    final jsonRes = super.convertResponse(response);
    return jsonRes.copyWith<ResultType>(
        body: $jsonDecoder.decode<Item>(jsonRes.body) as ResultType);
  }
}

final $jsonDecoder = $CustomJsonDecoder(generatedMapping);

// ignore: unused_element
String? _dateToJson(DateTime? date) {
  if (date == null) {
    return null;
  }

  final year = date.year.toString();
  final month = date.month < 10 ? '0${date.month}' : date.month.toString();
  final day = date.day < 10 ? '0${date.day}' : date.day.toString();

  return '$year-$month-$day';
}
